//=============================================================================
// Olivia Engine - Battle Sys Order Turn Battle - for RPG Maker MV version 1.6.1
// Olivia_BattleSysOTB.js
//=============================================================================
 /*:
 * @plugindesc <BattleSysOTB> for RPG Maker MV version 1.6.1.
 * @author Fallen Angel Olivia
 *
 * @help
 * This is a RPG Maker MV plugin that changes the battle system to have a turn
 * order system where battlers act immediately after inputting actions. These
 * actions can influence the order position of battlers in the current turn or
 * the next turn. The turn order is displayed to the top of the screen and gives
 * the player a clear understanding on whose turn it will be making it easier
 * for the player to formulate strategies and adapt to the situation in battle.
 *
 * This plugin requires YEP Battle Engine Core because it uses a lot of of the
 * code used to make the battle system feel natural. This is also to utilize
 * the key functions that come with the Battle Engine Core to make the more
 * interesting effects of the Order Turn Battle work smoother.
 *
 *
 *
 * ------------
 * Instructions
 * ------------
 *
 * If you are using other plugins, place this plugin as close to the BOTTOM of
 * the plugin list as you can or else some features of the other plugins may
 * override the battle system and it will not work properly.
 *
 *
 *
 * -----------------
 * Plugin Parameters
 * -----------------
 *
 * Mechanics: This section in the plugin parameters lets you change how the
 * battle system operates like automatically converting Item and Skill speed
 * into a notetag effect for OTB. This also lets you decide if some mechanics
 * will work in OTB or not like Action Times and how to position the extra
 * actions added to the turn order. Also determine if the AGI calculated for
 * the position in the turn order to be static or random.
 *
 * Visuals: This section lets you decide how the visuals added to the battle
 * system will look. This will mostly affect the turn order display. There is
 * not too much to customize except for some text, colors, and font sizes,
 * because everything is made to look compact in order to maintain efficiency
 * and not consume too many of the game's resources when it is in operation.
 *
 *
 *
 * --------
 * Notetags
 * --------
 *
 * Skill and Item Notetags:
 *
 * <OTB User Next Turn: +x>
 * <OTB User Next Turn: -x>
 * Change the user's turn order position for the next turn upon using this
 * skill or item. This will only occur once upon usage, no matter how many times
 * the battler hits the target.
 *
 * <OTB Target Current Turn: +x>
 * <OTB Target Current Turn: -x>
 * <OTB Target Next Turn: +x>
 * <OTB Target Next Turn: -x>
 * <OTB Target Follow Turn: +x>
 * <OTB Target Follow Turn: -x>
 * Change the target's turn order position for the current turn, the next turn,
 * or the following turn. If you are using the 'Follow' version of the notetag,
 * the turn it will modify will depend on if the target has acted during the
 * current turn. If it has acted, then it will affect the next turn, otherwise,
 * the current turn. Successfully attacking the target multiple times will also
 * affect the target multiple times.
 *
 * <OTB User Add Current Turn Actions: x>
 * <OTB User Add Next Turn Actions: x>
 * Add x actions to the current turn or the next turn for the user. This will
 * only be added once no matter how many times the battler hits the target.
 *
 * <OTB Target Add Current Turn Actions: x>
 * <OTB Target Add Next Turn Actions: x>
 * Add x actions to the current turn or the next turn for the target. If the
 * target is targeted multiple times, the target will gain actions multiple
 * times so please be cautious when using this.
 *
 *
 *
 * ---------------
 * Plugin Commands
 * ---------------
 * 
 * Because this is made with Battle Engine Core, you can change your game away
 * from OTB if you want to. However, if you do, make sure you have the plugin
 * parameter: "Force Battle System?" set to false.
 *
 * setBattleSys OTB
 * This sets the battle system to Order Turn Battle
 *
 * setBattleSys DTB
 * This sets the battle system to Default Turn Battle
 *
 *
 *
 * -------------------
 * W A R N I N G ! ! !
 * -------------------
 *
 * This plugin is made for RPG Maker MV versions 1.6.1 and below. If you update
 * RPG Maker MV past that and this plugin breaks, I am NOT responsible for it.
 *
 * -------------
 * Compatibility
 * -------------
 *
 * This plugin is compatible with the following plugins:
 *
 * - YEP Core Engine
 * - YEP Battle Engine Core
 * - YEP Action Sequence Packs 1, 2, 3
 * - YEP Animated Sideview Enemies
 * - YEP Counter Control
 * - YEP Battle AI Core
 * - YEP Battle Select Cursor
 * - YEP Buffs & States Core
 * - YEP Damage Core
 * - YEP Element Core
 * - YEP Target Core
 * - YEP Skill Core
 * - YEP Instant Cast
 * - YEP Item Core
 * - YEP Equip Core
 * - YEP Party System
 * - YEP Actor Party Switch
 * - YEP Job Points
 * - YEP Base Troop Events
 * - YEP Swap Enemies
 *
 * Place this plugin under those in the Plugin Manager list. Otherwise, the
 * effects of the plugins under this plugin may not work properly. I am NOT
 * responsible for the compatibility of plugins not shown in the above list.
 *
 * ------------
 * Terms of Use
 * ------------
 * 
 * 1. These plugins may be used in free or commercial games.
 * 2. 'Fallen Angel Olivia' and 'Yanfly' must be given credit in your games.
 * 3. You are allowed to edit the code.
 * 4. Do NOT change the filename, parameters, and information of the plugin.
 * 5. You are NOT allowed to redistribute these Plugins.
 * 6. You may NOT take code for your own released Plugins without credit.
 *
 * -------
 * Credits
 * -------
 *
 * If you are using this plugin, credit the following people:
 * 
 * - Fallen Angel Olivia
 * - Yanfly
 *
 * @param 
 * @param 
 * @param ATTENTION!!!
 * @default READ THE HELP FILE
 * @param 
 * @param 
 *
 * @param Warning OTB 
 * @text !!!!! WARNING !!!!!
 * @parent Order Turn Battle
 * @default Requires YEP_BattleEngineCore
 *
 * @param 
 * @param 
 *
 * @param OTB Force Battle System
 * @text Force Battle System?
 * @parent Order Turn Battle
 * @type boolean
 * @on On
 * @off Off
 * @desc Forces the OTB battle system no matter what your Battle Engine Core setting is.
 * @default true
 *
 * @param OTB Mechancs
 * @text Mechanics
 * @parent Order Turn Battle
 *
 * @param OTB Mechanics Action Speed Convert
 * @text Action Speed Convert
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Converts action speed into a <OTB User Next Turn: +x> notetag for items and skills
 * @default true
 *
 * @param OTB Mechanics Buff Debuff AGI Convert
 * @text Buff/Debuff AGI Convert
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Convert AGI buffs/debuffs into <OTB Target Next Turn: +x> notetag for items and skills
 * @default true
 *
 * @param OTB Mechanics Added Action Times
 * @text Added Action Times
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Allow Added Action Times in this battle system?
 * @default true
 *
 * @param OTB Mechanics Action Time Order Randomize
 * @text Randomize Position
 * @parent OTB Mechanics Added Action Times
 * @type boolean
 * @on On
 * @off Off
 * @desc Randomize the positions of newly added actions in the turn order after the first initial position?
 * @default true
 *
 * @param OTB Mechanics Enable Party Window
 * @text Enable Party Window?
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Gives access to the Party Command Window (Fight/Escape window)
 * @default false
 *
 * @param OTB Mechanics Escape Actor Window
 * @text Escape in Actor Window
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Add the Escape command in the actor window?
 * @default true
 *
 * @param OTB Mechanics Remove Restrict Current
 * @text Current Turn Wakeup
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Add battlers back to the current turn's order when they wake up from a restriction state?
 * @default true
 *
 * @param OTB Mechanics Remove Restrict Next
 * @text Next Turn Wakeup
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc Add battlers back to the next turn's order when they wake up from a restriction state?
 * @default true
 *
 * @param OTB Mechanics Static AGI Calculation
 * @text Static AGI Calculation
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc If on, calculate speed on static AGI. If off, calculate speed on random AGI.
 * @default true
 *
 * @param OTB Mechanics Stun Wakeup First
 * @text Stun Wakeup First
 * @parent OTB Mechancs
 * @type boolean
 * @on On
 * @off Off
 * @desc If on, when waking up from a stun, be first in position on the next turn
 * @default true
 *
 * @param OTB Mechanics Stun Wakeup Clamp
 * @text Clamp Turn Effects
 * @parent OTB Mechanics Stun Wakeup First
 * @type boolean
 * @on On
 * @off Off
 * @desc Prevent others from going past waking battlers for turn manipulation effects
 * @default true
 *
 * @param OTB Visuals
 * @text Visuals
 * @parent Order Turn Battle
 *
 * @param OTB Sprite Background Colors
 * @text Sprite Background Colors
 * @parent OTB Visuals
 *
 * @param OTB Background Actor Color
 * @text Actors
 * @parent OTB Sprite Background Colors
 * @desc Background color used for actors in the turn order
 * @default rgba(128, 160, 255, 0.6)
 *
 * @param OTB Background Enemy Color
 * @text Enemies
 * @parent OTB Sprite Background Colors
 * @desc Background color used for enemies in the turn order
 * @default rgba(255, 100, 80, 0.6)
 *
 * @param OTB Turn Order Display
 * @text Turn Order Display
 * @parent OTB Visuals
 *
 * @param OTB Display X
 * @text Display X
 * @parent OTB Turn Order Display
 * @type number
 * @desc The x position of the Turn Order Display
 * @default 48
 *
 * @param OTB Display Y
 * @text Display Y
 * @parent OTB Turn Order Display
 * @type number
 * @desc The y position of the Turn Order Display
 * @default 18
 *
 * @param OTB Display Help Window Move Y
 * @text Move to Y (During)
 * @parent OTB Turn Order Display
 * @type number
 * @desc Move to this Y position when Help Window is open
 * @default 18
 *
 * @param OTB Display Help Window Move Speed
 * @text Move Speed (During)
 * @parent OTB Turn Order Display
 * @type number
 * @desc Move speed when Help Window is open
 * @default 16
 *
 * @param OTB Display Current Text
 * @text Current Turn Text
 * @parent OTB Turn Order Display
 * @desc Text to display for current turn
 * @default CURRENT
 *
 * @param OTB Display Current Size
 * @text Font Size
 * @parent OTB Display Current Text
 * @type number
 * @desc Font size for current turn text
 * @default 20
 *
 * @param OTB Display Next Text
 * @text Next Turn Text
 * @parent OTB Turn Order Display
 * @desc Text to display for next turn
 * @default NEXT
 *
 * @param OTB Display Next Size
 * @text Font Size
 * @parent OTB Display Next Text
 * @type number
 * @desc Font size for next turn text
 * @default 20
 *
 * @param OTB Sprite Properties
 * @text Sprite Properties
 * @parent OTB Visuals
 *
 * @param OTB Sprite Move Duration
 * @text Move Duration
 * @parent OTB Sprite Properties
 * @type number
 * @min 1
 * @desc Number of frames to move the sprite
 * @default 20
 *
 * @param OTB Sprite Opacity Speed
 * @text Opacity Speed
 * @parent OTB Sprite Properties
 * @type number
 * @min 1
 * @desc How fast the sprite changes its opacity
 * @default 16
 *
 * @param OTB Battle Scene Properties
 * @text Battle Scene
 * @parent OTB Visuals
 *
 * @param OTB Help Window Y
 * @text Help Window Y
 * @parent OTB Battle Scene Properties
 * @type number
 * @desc Y coordinate of the help window
 * @default 92
 *
 * @param OTB Log Window Y
 * @text Log Window Y
 * @parent OTB Battle Scene Properties
 * @type number
 * @desc Y coordinate of the log window
 * @default 92
 *
 */
//=============================================================================

var _0x380f=['_spriteContainer','updateClearUnableBattlers','hide','clearResult','<OTB\x20Target\x20Next\x20Turn:\x20-1>','___Game_Battler_consumeItem___','_width2','_createdFirstTurnActionOrders','otbFailedEscape','processEscape','selectNextCommand','splice','_width1','createConstants','removeChild','characterIndex','OTB\x20Background\x20Actor\x20Color','startTurn','BackgroundEnemyColor','updateShiftOrder','___BattleManager_isTurnBased___','_otbTimesActedThisTurn','onBattleStart','normalColor','_nextTurnActionBattlers','_instance','startAction','_helpWindowY','svBattlerName','OctoBattle','description','___Scene_Battle_createHelpWindow___','YEP_ImprovedBattlebacks','_background1Sprite','___Game_Battler_onTurnEnd___','selectPreviousCommand','getNextSubject','BEC','ActionTimeOrderRandomize','updateStateTurns','escape','updateBattleManagerRequests','OTB','currentAction','OTB\x20Sprite\x20Opacity\x20Speed','updateBattlebackGroupRemove','___BattleManager_selectPreviousCommand___','_requestNextTurnUpdateInstantly','createBattlerSpriteAtEnd','makeCommandList','endOTBAction','abs','_phase','createBackground1Sprite','applyOTBAddAction','_back1Sprite','drawBackgroundLines','parameters','_otbFailedEscape','OTB\x20Display\x20Current\x20Text','globalAlpha','_requestCurrentTurnUpdateInstantly','length','_logWindow','undecided','_baseScale','onActionEndStateEffects','createNewSpritesFor','getSelectedBattleTargets','createReturnedBattlerSprite','DisplayY','loadSvActor','OTB\x20Display\x20X','___BattleManager_startAction___','getNextSubjectOTB','canEscape','_battleField','YEP_X_AnimatedSVEnemies','disposeSprite','Enemy\x20','startInput','_actionBattlers','_requestNextTurnUpdate','makeActionOrdersOTB','_requestClearUnableBattlers','OTB\x20Mechanics\x20Buff\x20Debuff\x20AGI\x20Convert','_requestNextTurnPreview','loadCharacter','___BattleManager_endAction___','_hideOTBTurnDisplay','currentSymbol','isPlaytest','turnCount','BattleManager_endAction','createForceActionFailSafes','ForceBattleSystem','___Game_BattlerBase_paySkillCost___','___BattleManager_processTurn___','ceil','PartyEnBattle','OTB\x20Display\x20Next\x20Size','HelpWindowMoveSpeed','anchor','otbClearActionOrdersOfUnableBattlersArray','_currentTurnSprites','___Game_Action_customEffectEval___','setupBattlerBitmapFrame','loadPreForceActionSettings','contents','index','commandEscape','___BattleManager_makeActionOrders___','hasSVBattler','addChild','addActor','forceAction','max','aliveMembers','Battle\x20System\x20OTB\x20Error','addEscapeCommand','createPreviewSprite','contentsOpacity','___Game_BattlerBase_hide___','removeState','OTB\x20Mechanics\x20Remove\x20Restrict\x20Next','___BattleManager_isDTB___','_battlerHue','OTB\x20Mechanics\x20Action\x20Speed\x20Convert','_actorCommandWindow','setupBattlerBitmapScale','input','requestMotionRefresh','lineTo','YEP_BuffsStatesCore','otbBuffDebuffAgiConvert','OTB\x20Sprite\x20Move\x20Duration','___BattleManager_startInput___','otbSetTurnPreviewItem','concat','_bigAppearance','YEP_InstantCast','isDead','canInput','isEnemy','update','AddedActionTimes','___Game_Party_removeActor___','isSideView','_scene','consumeItem','otbInsertRevivalActionOrders','makeActionTimes','onTurnEnd','otbInfinityClamp','___Game_Battler_isUndecided___','OTB\x20Mechanics\x20Enable\x20Party\x20Window','___BattleManager_getNextSubject___','_otbTurnPreview','otb','addState','Game_Enemy_battlerName','_back2Sprite','applyOTBEffect','_activeOTBActor','createBattlerSprite','addLoadListener','_requestCurrentTurnSpriteReorder','isBattleSystem','setPreview','EscapeActorWindow','updateWindowPosition','boxWidth','___Game_Action_applyItemUserEffect___','_processingForcedAction','agi','updateOpacity','RemoveRestrictCurrent','CurrentTurnText','_otbBuffDebuffAgiConvert','_hidden','Param','_x2','call','allBattleMembers','item','shift','PartyShowBattle','___Game_Battler_onBattleEnd___','_subjectSprite','push','updateNextTurnPreviewTargets','___Game_Battler_makeSpeed___','___Game_Battler_customEffectEval___','resetFontSettings','_context','_tempBattler','printError','loadSvEnemy','_battlerSprite','___Window_BattleSkill_initialize___','standardPadding','StatusWidth','OTB\x20Background\x20Enemy\x20Color','BECSystem','characterName','_helpWindow','_otbDisplayWindow','drawText','isUndecided','min','speed','updatePosition','OTB\x20Mechanics\x20Stun\x20Wakeup\x20First','_updateReady','OTB\x20Mechanics\x20Action\x20Time\x20Order\x20Randomize','_preForcePhase','clearActor','otbAddActionTimes','_battlerName','otbClearTurnPreview','bitmap','_setDirty','speedOTB','_largeScale','_opacityRate','onAllActionsEnd','makeSpeed','battlerHue','guard','otbNextTurnChange','deactivate','addWindow','isActor','otbPostPartySwitch','___BattleManager_startTurn___','customEffectEval','OTB\x20Mechanics\x20Remove\x20Restrict\x20Current','StunWakeUpFirst','_moveDuration','KELYEP_DragonBones','isAlive','spriteStepBack','OTB\x20Display\x20Next\x20Text','_otbInstantCast','setupBattlerBitmap','select','setupWindowConstants','scale','_disposedSprites','otbClearActionOrdersOfUnableBattlers','addChildAt','StunWakeUpClamp','_previewItem','changeActor','paySkillCost','StaticAgiCalculation','otbAddActionCost','_subject','createNewSprites','otbAddBattler','_helpMoveSpeed','displayEscapeFailureMessage','EnablePartyWindow','endBattle','loadEnemy','match','postPartySwitch','makeActions','bind','otbActionTimesModification','isReplacedByDragonBonesBattler','contains','createActorCommandWindow','___Game_BattlerBase_appear___','___InstantBattleManager_startAction___','initMembers','clamp','otbTurnShiftCost','___BattleManager_forceAction___','prototype','EFFECT_ADD_BUFF','otbForceAction','dimColor1','constructor','Actor\x20','setBattler','_background2Sprite','___Game_Battler_removeState___','___BattleManager_selectNextCommand___','savePreForceActionSettings','stroke','<OTB\x20Target\x20Next\x20Turn:\x20+1>','OTB\x20Mechanics\x20Static\x20AGI\x20Calculation','guardSkillId','___Game_Battler_performActionEnd___','_nextTurnSprites','_previewSprites','BackgroundActorColor','createBackground2Sprite','___Scene_Battle_commandEscape___','updateZCoordinates','OTB\x20Display\x20Help\x20Window\x20Move\x20Y','moveTo','HelpWindowMoveY','NextTurnFontSize','sort','___BattleManager_displayEscapeFailureMessage___','children','Window_Selectable_deactivate','_selectionEffectCount','round','rgba(255,\x20255,\x20255,\x201)','otbInstanceName','___Game_Action_speed___','isDTB','HelpWindowNewY','_disposeState','ActiveBattlerMove','detectOtbInstantCast','otbInsertActionOrderAtEnd','removeCurrentAction','OTB\x20Display\x20Current\x20Size','_targetX','inputtingAction','isInstantCast','___Window_ActorCommand_makeCommandList___','_previewMode','note','restore','actorId','_actor','randomInt','_iconWidth','battlerName','updateNextTurnPreviewClear','processTurn','_startedInstantCasting','makeDeepCopy','subject','_actions','ActionSpeedConvert','code','_requestNextTurnPreviewClear','giveTurnSpritesToNewArray','otbInsertRevivalActionOrder','updateBattlerBitmap','SelectBattlerMove','startOTBInput','left','opacity','fill','_requestNextTurnSpriteReorder','_battler','updateMovement','isOTB','canMove','isTurnBased','setBPSubject','removeActor','battleFieldDepthCompare','drawOutlinePolygon','otbSetSubject','Window_ActorCommand_initialize','OTB\x20Log\x20Window\x20Y','otbRemoveBattler','checkDragonbones','attack','updateNextTurnPreview','YEP_BattleEngineCore','updateSelectionEffect','lineHeight','cancel','applyItemUserEffect','endAction','___Window_BattleEnemy_initialize___','otbDisplayWindow','OpacitySpeed','effects','drawBackgroundText','setupVariableConstants','___BattleManager_endBattle___','setBlendColor','Enabled','otbCreateTurnPreview','_actors','___Window_Selectable_select___','___BattleManager_initMembers___','updateTurnSpriteLocations','___Game_Battler_addState___','getSpritePriority','appear','Battle','_instantCasting','_x1','actor','___Game_Battler_onBattleStart___','___InstantBattleManager_endAction___','_requestCurrentTurnUpdate','save','NextTurnText','YEP_PartySystem','fillStyle','refresh','initialize','OTB\x20Display\x20Help\x20Window\x20Move\x20Speed','createOTBDisplayWindow','lineWidth','filter','RemoveRestrictNext','___Scene_Battle_postPartySwitch___','height','indexOf','MoveDuration','attackSkillId','updateNextTurnPreviewUser','stop','SideBattleUI','setHandler','updateReorderSprites','___Scene_Battle_createActorCommandWindow___','otbCheckIfBattlerIsUnable','dataId','width','OTB\x20Mechanics\x20Added\x20Action\x20Times','apply','changePaintOpacity','DisplayX','loadBattlerSpriteBitmap','___Game_Party_addActor___','onBattleEnd','floor','OTB\x20Help\x20Window\x20Y','makeActionOrders','inBattle','_actionForcedBattler','create','_sourceArray','getAllIndices','turn'];(function(_0xc8809d,_0x380f6b){var _0x248750=function(_0x5d86b9){while(--_0x5d86b9){_0xc8809d['push'](_0xc8809d['shift']());}};_0x248750(++_0x380f6b);}(_0x380f,0x98));var _0x2487=function(_0xc8809d,_0x380f6b){_0xc8809d=_0xc8809d-0x0;var _0x248750=_0x380f[_0xc8809d];return _0x248750;};var Imported=Imported||{};Imported['Olivia_OctoBattle']=!![];var Olivia=Olivia||{};Olivia[_0x2487('0x13c')]=Olivia['OctoBattle']||{};var parameters=$plugins[_0x2487('0xff')](function(_0x523f33){return _0x523f33[_0x2487('0x13d')]['contains']('<BattleSysOTB>');})[0x0][_0x2487('0x158')];Olivia['OctoBattle']['OTB']={'Enabled':!![],'ForceBattleSystem':eval(parameters['OTB\x20Force\x20Battle\x20System']),'ActionSpeedConvert':eval(parameters[_0x2487('0x19e')]),'BuffDebuffAgiConvert':eval(parameters[_0x2487('0x174')]),'AddedActionTimes':eval(parameters[_0x2487('0x10f')]),'ActionTimeOrderRandomize':eval(parameters[_0x2487('0x3e')]),'EnablePartyWindow':eval(parameters[_0x2487('0x3')]),'EscapeActorWindow':eval(parameters['OTB\x20Mechanics\x20Escape\x20Actor\x20Window']),'RemoveRestrictCurrent':eval(parameters[_0x2487('0x54')]),'RemoveRestrictNext':eval(parameters[_0x2487('0x19b')]),'StaticAgiCalculation':eval(parameters[_0x2487('0x8c')]),'StunWakeUpFirst':eval(parameters[_0x2487('0x3c')]),'StunWakeUpClamp':eval(parameters['OTB\x20Mechanics\x20Stun\x20Wakeup\x20Clamp']),'BackgroundActorColor':String(parameters[_0x2487('0x12f')]),'BackgroundEnemyColor':String(parameters[_0x2487('0x32')]),'DisplayX':Number(parameters[_0x2487('0x167')]),'DisplayY':Number(parameters['OTB\x20Display\x20Y']),'HelpWindowMoveY':Number(parameters[_0x2487('0x95')]),'HelpWindowMoveSpeed':Number(parameters[_0x2487('0xfc')]),'CurrentTurnText':String(parameters[_0x2487('0x15a')]),'CurrentTurnFontSize':Number(parameters[_0x2487('0xa9')]),'NextTurnText':String(parameters[_0x2487('0x5a')]),'NextTurnFontSize':Number(parameters[_0x2487('0x183')]),'MoveDuration':Number(parameters[_0x2487('0x1a6')]),'OpacitySpeed':Number(parameters[_0x2487('0x14b')]),'HelpWindowNewY':Number(parameters[_0x2487('0x117')]),'LogWindowNewY':Number(parameters[_0x2487('0xd3')])};if(Imported[_0x2487('0xd8')]&&Olivia[_0x2487('0x13c')][_0x2487('0x149')]['Enabled']){Olivia[_0x2487('0x13c')][_0x2487('0xef')]=Olivia[_0x2487('0x13c')][_0x2487('0xef')]||{};Object['defineProperties'](Array[_0x2487('0x7f')],{'getAllIndices':{'enumerable':![],'value':function(_0x230aa4){var _0xd3a45a=[];for(var _0x1bb779=0x0;_0x1bb779<this[_0x2487('0x15d')];_0x1bb779++){if(this[_0x1bb779]===_0x230aa4){_0xd3a45a[_0x2487('0x25')](_0x1bb779);}}return _0xd3a45a;}}});Bitmap[_0x2487('0x7f')][_0x2487('0xd0')]=function(_0x486924,_0x2e70f1,_0x2d1270,_0xe9d8ef,_0x27ede0,_0x4912ee){var _0x2bcc1a=this[_0x2487('0x2a')];_0x2bcc1a[_0x2487('0xf6')]();_0x2bcc1a['beginPath']();_0x2bcc1a[_0x2487('0x96')](_0x486924[0x0],_0x486924[0x1]);for(var _0x570372=0x2;_0x570372<_0x486924['length'];_0x570372+=0x2){_0x2bcc1a[_0x2487('0x1a3')](_0x486924[_0x570372],_0x486924[_0x570372+0x1]);}_0x2bcc1a[_0x2487('0x1a3')](_0x486924[0x0],_0x486924[0x1]);_0x2bcc1a['strokeStyle']=_0x2e70f1;_0x2bcc1a[_0x2487('0xfe')]=_0xe9d8ef;if(_0x4912ee){_0x2bcc1a[_0x2487('0x8a')]();}_0x2bcc1a[_0x2487('0x15b')]=_0x27ede0;_0x2bcc1a[_0x2487('0xf9')]=_0x2d1270;_0x2bcc1a[_0x2487('0xc6')]();_0x2bcc1a[_0x2487('0x15b')]=0x1;_0x2bcc1a[_0x2487('0xb0')]();this[_0x2487('0x45')]();};Yanfly[_0x2487('0x1c')]['BECStartActCmd']=!![];if(Olivia[_0x2487('0x13c')][_0x2487('0x149')]['ForceBattleSystem']){Yanfly[_0x2487('0x1c')][_0x2487('0x33')]=_0x2487('0x6');}Yanfly[_0x2487('0x1c')][_0x2487('0x22')]=![];Yanfly[_0x2487('0x1c')][_0x2487('0x182')]=![];DataManager[_0x2487('0x1a5')]=function(_0x49cc00){if(BattleManager[_0x2487('0xca')]()&&Olivia[_0x2487('0x13c')][_0x2487('0x149')]['BuffDebuffAgiConvert']&&!!_0x49cc00&&!_0x49cc00['_otbBuffDebuffAgiConvert']){_0x49cc00[_0x2487('0x1a')]=!![];for(var _0x544b4a=0x0;_0x544b4a<_0x49cc00[_0x2487('0xe1')]['length'];_0x544b4a++){var _0x79c1af=_0x49cc00[_0x2487('0xe1')][_0x544b4a];if(_0x79c1af['code']===Game_Action[_0x2487('0x80')]&&_0x79c1af['dataId']===0x6){_0x49cc00['note']+=_0x2487('0x8b');}if(_0x79c1af[_0x2487('0xbd')]===Game_Action[_0x2487('0x80')]&&_0x79c1af[_0x2487('0x10d')]===0x6){_0x49cc00['note']+=_0x2487('0x123');}}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xea')]=BattleManager[_0x2487('0x7b')];BattleManager[_0x2487('0x7b')]=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xea')][_0x2487('0x1e')](this);if(this[_0x2487('0xca')]()){this['_nextTurnActionBattlers']=[];this['_createdFirstTurnActionOrders']=![];this[_0x2487('0xf5')]=![];this[_0x2487('0x15c')]=![];this[_0x2487('0x171')]=![];this[_0x2487('0x14e')]=![];this['_requestShiftTurnOrder']=![];this[_0x2487('0x173')]=![];this[_0x2487('0x175')]=null;this[_0x2487('0xbe')]=![];this['_requestCurrentTurnSpriteReorder']=![];this[_0x2487('0xc7')]=![];this[_0x2487('0x178')]=![];}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x19c')]=BattleManager[_0x2487('0xa2')];BattleManager[_0x2487('0xa2')]=function(){if(this[_0x2487('0xca')]()){return![];}else{return Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x19c')][_0x2487('0x1e')](this);}};BattleManager[_0x2487('0xca')]=function(){if(Olivia['OctoBattle'][_0x2487('0x149')][_0x2487('0x17e')]){return!![];}else{return this[_0x2487('0xf')](_0x2487('0x6'));}};Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x133')]=BattleManager[_0x2487('0xcc')];BattleManager[_0x2487('0xcc')]=function(){if(this[_0x2487('0xca')]()){return!![];}else{return Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x133')]['call'](this);}};BattleManager['otbDisplayWindow']=function(){return SceneManager[_0x2487('0x1b3')][_0x2487('0x36')];};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xe4')]=BattleManager[_0x2487('0x6f')];BattleManager[_0x2487('0x6f')]=function(_0x25b6b8){Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___BattleManager_endBattle___'][_0x2487('0x1e')](this,_0x25b6b8);this[_0x2487('0x178')]=!![];};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x1a7')]=BattleManager[_0x2487('0x16f')];BattleManager['startInput']=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x1a7')][_0x2487('0x1e')](this);if(this['isOTB']()&&this[_0x2487('0x153')]!==_0x2487('0x11e')){this[_0x2487('0x130')]();}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x52')]=BattleManager[_0x2487('0x130')];BattleManager[_0x2487('0x130')]=function(){if(this[_0x2487('0x159')]){this[_0x2487('0x127')]();}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x52')][_0x2487('0x1e')](this);}};BattleManager[_0x2487('0x127')]=function(){this[_0x2487('0x159')]=![];$gameParty[_0x2487('0x1a2')]();};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x180')]=BattleManager[_0x2487('0xb7')];BattleManager['processTurn']=function(){if(this['isOTB']()&&this[_0x2487('0x69')][_0x2487('0x50')]()){this[_0x2487('0xc3')]();}else{Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x180')][_0x2487('0x1e')](this);}};BattleManager['startOTBInput']=function(){this[_0x2487('0x153')]=_0x2487('0x1a1');var _0x5cbfb2=this[_0x2487('0x69')];if(!!_0x5cbfb2){BattleManager[_0x2487('0x65')](_0x5cbfb2[_0x2487('0x18c')](),_0x2487('0x15f'));if(!_0x5cbfb2[_0x2487('0x1ad')]()){_0x5cbfb2[_0x2487('0x73')]();this[_0x2487('0x139')]();}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x4')]=BattleManager['getNextSubject'];BattleManager[_0x2487('0x143')]=function(){if(this[_0x2487('0xca')]()){this[_0x2487('0x69')]=this[_0x2487('0x169')]();if(!!this[_0x2487('0x69')]){this[_0x2487('0x69')][_0x2487('0x73')]();}this['otbDisplayWindow']()['updateShiftOrder']();return this['_subject'];}else{return Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x4')][_0x2487('0x1e')](this);}};BattleManager[_0x2487('0x169')]=function(){for(;;){var _0x55a50e=this[_0x2487('0x170')][_0x2487('0x21')]();if(!_0x55a50e){return null;}if(_0x55a50e['isBattleMember']()&&_0x55a50e[_0x2487('0x58')]()){return _0x55a50e;}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x14d')]=BattleManager[_0x2487('0x142')];BattleManager[_0x2487('0x142')]=function(){if(this[_0x2487('0xca')]()){this['_activeOTBActor']=this['_actorIndex'];this['_subject']=null;this['changeActor'](-0x1,_0x2487('0x15f'));}else{Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x14d')][_0x2487('0x1e')](this);}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x9a')]=BattleManager[_0x2487('0x6d')];BattleManager['displayEscapeFailureMessage']=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x9a')][_0x2487('0x1e')](this);if(this[_0x2487('0xca')]()){this[_0x2487('0xdd')]();this[_0x2487('0x159')]=!![];}};BattleManager[_0x2487('0xd1')]=function(){BattleManager[_0x2487('0x65')](this[_0x2487('0xb')],_0x2487('0x15f'));this[_0x2487('0x69')]=this['actor']();};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x88')]=BattleManager[_0x2487('0x129')];BattleManager[_0x2487('0x129')]=function(){if(this[_0x2487('0xca')]()){if(this[_0x2487('0x69')]){this['startAction']();}else{this[_0x2487('0xd1')]();this[_0x2487('0xc3')]();}}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___BattleManager_selectNextCommand___']['call'](this);}};Olivia['OctoBattle'][_0x2487('0xef')]['___BattleManager_startAction___']=BattleManager[_0x2487('0x139')];BattleManager[_0x2487('0x139')]=function(){if(Imported[_0x2487('0x1ab')]){this[_0x2487('0xa6')]();}Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x168')]['call'](this);};if(Imported[_0x2487('0x1ab')]){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x7a')]=BattleManager['startAction'];BattleManager[_0x2487('0x139')]=function(){this['_startedInstantCasting']=!![];Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x7a')][_0x2487('0x1e')](this);};}Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x177')]=BattleManager[_0x2487('0xdd')];BattleManager[_0x2487('0xdd')]=function(){if(this[_0x2487('0xca')]()){this[_0x2487('0x151')]();}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x177')]['call'](this);}};if(Imported[_0x2487('0x1ab')]){Olivia['OctoBattle']['Battle']['___InstantBattleManager_endAction___']=BattleManager[_0x2487('0xdd')];BattleManager[_0x2487('0xdd')]=function(){if(this['isOTB']()&&this[_0x2487('0xf0')]){this['endActorInstantCast']();}else{Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0xf4')][_0x2487('0x1e')](this);}this[_0x2487('0xb8')]=![];};}BattleManager[_0x2487('0x151')]=function(){this['_phase']='turn';if(this[_0x2487('0x5b')]){this[_0x2487('0x5b')]=![];if(this[_0x2487('0x69')][_0x2487('0x1ae')]()){this[_0x2487('0x170')]['unshift'](this[_0x2487('0x69')]);this[_0x2487('0x69')][_0x2487('0x73')]();}return Yanfly[_0x2487('0x144')][_0x2487('0x17c')]['call'](this);}if(this[_0x2487('0x69')]){this[_0x2487('0x69')][_0x2487('0x59')]();if(Imported[_0x2487('0x1a4')]){this[_0x2487('0x69')][_0x2487('0x161')]();}this[_0x2487('0x69')][_0x2487('0x49')]();this[_0x2487('0x69')][_0x2487('0xa8')]();}if(this[_0x2487('0x15')]){this[_0x2487('0x153')]=this[_0x2487('0x3f')];this['_processingForcedAction']=![];}if(this[_0x2487('0x18a')]()){return;}this[_0x2487('0x40')]();this[_0x2487('0x69')]=null;this[_0x2487('0x61')]();Yanfly[_0x2487('0x144')][_0x2487('0x17c')][_0x2487('0x1e')](this);};BattleManager['otbClearActionOrdersOfUnableBattlers']=function(){var _0x2347e6=this[_0x2487('0x186')](this[_0x2487('0x170')]);var _0xed5642=this[_0x2487('0x186')](this[_0x2487('0x137')]);this['_requestClearUnableBattlers']=_0x2347e6||_0xed5642;};BattleManager[_0x2487('0x186')]=function(_0x481d7a){var _0x1c3815=![];for(var _0x13bfec=0x0;_0x13bfec<_0x481d7a[_0x2487('0x15d')];_0x13bfec++){var _0x31ee69=_0x481d7a[_0x13bfec];if(!!_0x31ee69){if(this[_0x2487('0x10c')](_0x31ee69,_0x481d7a)){_0x481d7a['splice'](_0x13bfec,0x1);_0x13bfec--;this[_0x2487('0xf5')]=!![];this[_0x2487('0x171')]=!![];_0x1c3815=!![];}}}return _0x1c3815;};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x7e')]=BattleManager[_0x2487('0x192')];BattleManager[_0x2487('0x192')]=function(_0x20b331){if(this[_0x2487('0xca')]()){if($gameTroop[_0x2487('0x17b')]()>0x0){_0x20b331[_0x2487('0x134')]-=0x1;this[_0x2487('0x81')](_0x20b331);}else if($gameTemp[_0x2487('0x17a')]()){var _0x1cad46='Forced\x20actions\x20do\x20not\x20work\x20on\x20turn\x200.\x20Please\x20use\x20turn\x201.';SceneManager[_0x2487('0x107')]();Graphics[_0x2487('0x2c')](_0x2487('0x195'),_0x1cad46);}}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___BattleManager_forceAction___'][_0x2487('0x1e')](this,_0x20b331);}};BattleManager['otbForceAction']=function(_0x30d210){if(this['_subject'])this[_0x2487('0x69')][_0x2487('0x122')]();this[_0x2487('0x17d')]();this[_0x2487('0x89')]();this[_0x2487('0x11a')]=_0x30d210;};BattleManager['otbCheckIfBattlerIsUnable']=function(_0x40ddd9,_0x36604e){if(_0x40ddd9[_0x2487('0x1ac')]()||_0x40ddd9['isHidden']()){return!![];}else if(!_0x40ddd9[_0x2487('0xcb')]()&&_0x36604e===this[_0x2487('0x170')]){return!![];}else if(!this['allBattleMembers']()[_0x2487('0x77')](_0x40ddd9)){return!![];}else if(!_0x40ddd9[_0x2487('0xcb')]()&&_0x36604e===this[_0x2487('0x137')]){var _0x1607ca=JsonEx[_0x2487('0xb9')](_0x40ddd9);_0x1607ca['_tempBattler']=!![];_0x1607ca[_0x2487('0x146')]();_0x1607ca['refresh']();return!_0x1607ca[_0x2487('0xcb')]();}else{return![];}};BattleManager[_0x2487('0x1b5')]=function(_0x531239){_0x531239[_0x2487('0x134')]=_0x531239[_0x2487('0x134')]||0x0;if(Olivia[_0x2487('0x13c')][_0x2487('0x149')]['RemoveRestrictCurrent']&&_0x531239[_0x2487('0x1b6')]()>_0x531239[_0x2487('0x134')]){this['otbInsertRevivalActionOrder'](_0x531239,this[_0x2487('0x170')]);}if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x100')]){this[_0x2487('0xc0')](_0x531239,this[_0x2487('0x137')]);}};BattleManager[_0x2487('0xc0')]=function(_0x3a168a,_0x1183d0){if(!_0x1183d0[_0x2487('0x77')](_0x3a168a)){if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x1b0')]){_0x3a168a[_0x2487('0x134')]=_0x3a168a[_0x2487('0x134')]||0x0;var _0x5bc998=Math[_0x2487('0x193')](_0x3a168a[_0x2487('0x1b6')]()-_0x3a168a[_0x2487('0x134')],0x1);}else{var _0x5bc998=0x1;}while(_0x5bc998--){_0x1183d0[_0x2487('0x25')](_0x3a168a);}this[_0x2487('0xdf')]()[_0x2487('0x164')](_0x3a168a,_0x1183d0===this['_actionBattlers']);}};BattleManager[_0x2487('0xa7')]=function(_0xaa97fc,_0x431dc2,_0x268e54){while(_0x268e54--){_0x431dc2[_0x2487('0x25')](_0xaa97fc);this[_0x2487('0xdf')]()[_0x2487('0x14f')](_0xaa97fc,_0x431dc2===this['_actionBattlers']);}};BattleManager[_0x2487('0xa6')]=function(){this[_0x2487('0x5b')]=![];if(!this[_0x2487('0xca')]()){return;}else if(!this['_subject']){return;}else if(!this[_0x2487('0x69')][_0x2487('0x14a')]()){return;}else if(!this[_0x2487('0x69')][_0x2487('0x14a')]()['item']()){return;}else{var _0x4bacf9=this[_0x2487('0x69')]['currentAction']()[_0x2487('0x20')]();this[_0x2487('0x5b')]=this['_subject'][_0x2487('0xac')](_0x4bacf9);}};BattleManager['getSpritePriority']=function(){if(this[_0x2487('0x69')]&&this[_0x2487('0x69')][_0x2487('0x50')]()){return 0x1;}else if(this['_subject']&&this[_0x2487('0x69')]['isEnemy']()){return 0x2;}else{return 0x0;}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x18e')]=BattleManager[_0x2487('0x118')];BattleManager['makeActionOrders']=function(){if(this[_0x2487('0xca')]()){this[_0x2487('0x172')]();this[_0x2487('0xdf')]()[_0x2487('0x6a')]();}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x18e')][_0x2487('0x1e')](this);}};BattleManager[_0x2487('0x172')]=function(){if(this['_createdFirstTurnActionOrders']){this[_0x2487('0x170')]=this['_nextTurnActionBattlers'];}this[_0x2487('0x137')]=[];this[_0x2487('0x137')]=this[_0x2487('0x137')]['concat']($gameParty[_0x2487('0x194')]());this[_0x2487('0x137')]=this[_0x2487('0x137')][_0x2487('0x1a9')]($gameTroop[_0x2487('0x194')]());this[_0x2487('0x137')]['forEach'](function(_0x4a0b72){_0x4a0b72[_0x2487('0x4a')]();});this[_0x2487('0x137')][_0x2487('0x99')](function(_0x56e580,_0x55353c){return _0x55353c[_0x2487('0x3a')]()-_0x56e580[_0x2487('0x3a')]();});if(!this[_0x2487('0x126')]){Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x18e')][_0x2487('0x1e')](this);}if(!this[_0x2487('0x126')]){this[_0x2487('0x75')](this[_0x2487('0x170')]);}this[_0x2487('0x61')]();this[_0x2487('0x75')](this[_0x2487('0x137')]);this['_createdFirstTurnActionOrders']=!![];};BattleManager['otbActionTimesModification']=function(_0x520dbe){if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x1b0')]){var _0x761596=this[_0x2487('0x1f')]();for(var _0x4aaa48=0x0;_0x4aaa48<_0x761596['length'];_0x4aaa48++){var _0x56674d=_0x761596[_0x4aaa48];if(!!_0x56674d&&_0x520dbe['contains'](_0x56674d)){var _0x3b1fb2=_0x520dbe[_0x2487('0x103')](_0x56674d);var _0x5226d5=_0x56674d[_0x2487('0x1b6')]()-0x1;while(_0x5226d5--){if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x145')]&&_0x56674d[_0x2487('0x3a')]()!==Infinity){var _0x17f4dc=Math[_0x2487('0xb3')](_0x520dbe[_0x2487('0x15d')]-_0x3b1fb2)+_0x3b1fb2;}else{var _0x17f4dc=_0x3b1fb2;}_0x520dbe[_0x2487('0x12a')](_0x17f4dc,0x0,_0x56674d);}}}}};BattleManager[_0x2487('0x4d')]=function(_0x218aee,_0x431349,_0x3deed6){if(_0x3deed6){var _0x80897d=this['_actionBattlers'];this['_requestCurrentTurnUpdate']=!![];this['_requestCurrentTurnSpriteReorder']=!![];}else{var _0x80897d=this[_0x2487('0x137')];this[_0x2487('0x171')]=!![];this[_0x2487('0xc7')]=!![];}if(_0x80897d['contains'](_0x218aee)){var _0x554f59=_0x80897d[_0x2487('0x11d')](_0x218aee);for(var _0x1fa612=_0x554f59[_0x2487('0x15d')]-0x1;_0x1fa612>=0x0;_0x1fa612--){_0x80897d[_0x2487('0x12a')](_0x554f59[_0x1fa612],0x1);}var _0x26b1a4=this[_0x2487('0x1')](_0x80897d);for(var _0x1fa612=0x0;_0x1fa612<_0x554f59[_0x2487('0x15d')];_0x1fa612++){var _0x5661d7=(_0x554f59[_0x1fa612]-_0x431349)[_0x2487('0x7c')](_0x26b1a4,_0x80897d[_0x2487('0x15d')]);_0x80897d['splice'](_0x5661d7,0x0,_0x218aee);}}};BattleManager[_0x2487('0x1')]=function(_0x33680c){if(Olivia['OctoBattle'][_0x2487('0x149')][_0x2487('0x63')]){for(var _0x6500bf=0x0;_0x6500bf<_0x33680c[_0x2487('0x15d')];_0x6500bf++){var _0x13c08d=_0x33680c[_0x6500bf];if(_0x13c08d[_0x2487('0x3a')]()!==Infinity){return _0x6500bf;}}return _0x6500bf;}else{return 0x0;}};BattleManager[_0x2487('0x6b')]=function(_0x410337){if(!!_0x410337&&this[_0x2487('0x1f')]()['contains'](_0x410337)){this[_0x2487('0xa7')](_0x410337,this[_0x2487('0x170')]);this[_0x2487('0xa7')](_0x410337,this[_0x2487('0x137')]);}};BattleManager[_0x2487('0xd4')]=function(_0x23aacb){this['otbClearActionOrdersOfUnableBattlers']();};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xa1')]=Game_Action[_0x2487('0x7f')][_0x2487('0x3a')];Game_Action[_0x2487('0x7f')]['speed']=function(){if(BattleManager[_0x2487('0xca')]()){return this[_0x2487('0x46')]();}else{return Olivia['OctoBattle']['Battle'][_0x2487('0xa1')]['call'](this);}};Game_Action[_0x2487('0x7f')][_0x2487('0x46')]=function(){if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x67')]){var _0x47c58b=this[_0x2487('0xba')]()['agi'];}else{var _0x3164b3=this['subject']()[_0x2487('0x16')];var _0x47c58b=_0x3164b3+Math['randomInt'](Math['floor'](0x5+_0x3164b3/0x4));}return _0x47c58b;};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x14')]=Game_Action[_0x2487('0x7f')]['applyItemUserEffect'];Game_Action[_0x2487('0x7f')][_0x2487('0xdc')]=function(_0x4e5ca2){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x14')][_0x2487('0x1e')](this,_0x4e5ca2);if(BattleManager['isOTB']()&&!!this[_0x2487('0x20')]()){DataManager[_0x2487('0x1a5')](this[_0x2487('0x20')]());this[_0x2487('0xa')](_0x4e5ca2);this[_0x2487('0x155')](_0x4e5ca2);}};Game_Action[_0x2487('0x7f')][_0x2487('0xa')]=function(_0x5bb317){if(_0x5bb317[_0x2487('0x3a')]()!==Infinity){var _0x32e547=0x0;var _0x4b2748=0x0;if(this['item']()[_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Follow Turn: ([\+\-]\d+)>/i)){if(BattleManager[_0x2487('0x170')]['contains'](_0x5bb317)){_0x32e547+=parseInt(RegExp['$1']);}else{_0x4b2748+=parseInt(RegExp['$1']);}}if(this[_0x2487('0x20')]()['note'][_0x2487('0x71')](/<OTB Target Current Turn: ([\+\-]\d+)>/i)){_0x32e547+=parseInt(RegExp['$1']);}if(this[_0x2487('0x20')]()[_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Next Turn: ([\+\-]\d+)>/i)){_0x4b2748+=parseInt(RegExp['$1']);}if(_0x32e547!==0x0){BattleManager[_0x2487('0x4d')](_0x5bb317,_0x32e547,!![]);}if(_0x4b2748!==0x0){BattleManager[_0x2487('0x4d')](_0x5bb317,_0x4b2748,![]);}}};Game_Action[_0x2487('0x7f')][_0x2487('0x155')]=function(_0x552f5b){if(this[_0x2487('0x20')]()[_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Add Current Turn (?:Action|Actions): (\d+)>/i)){var _0x9896aa=parseInt(RegExp['$1']);_0x552f5b[_0x2487('0x41')](_0x9896aa,!![]);}if(this[_0x2487('0x20')]()[_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Add Next Turn (?:Action|Actions): (\d+)>/i)){var _0x9896aa=parseInt(RegExp['$1']);_0x552f5b[_0x2487('0x41')](_0x9896aa,![]);}};Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x17f')]=Game_BattlerBase[_0x2487('0x7f')][_0x2487('0x66')];Game_BattlerBase['prototype'][_0x2487('0x66')]=function(_0x1ab533){Olivia[_0x2487('0x13c')]['Battle']['___Game_BattlerBase_paySkillCost___'][_0x2487('0x1e')](this,_0x1ab533);if($gameParty[_0x2487('0x119')]()&&BattleManager[_0x2487('0xca')]()){this[_0x2487('0x7d')]();this[_0x2487('0x68')]();}};Game_BattlerBase[_0x2487('0x7f')][_0x2487('0x7d')]=function(){var _0x195263=0x0;if(!!this[_0x2487('0x14a')]()&&this[_0x2487('0x14a')]()[_0x2487('0x20')]()){var _0x4b3804=this[_0x2487('0x14a')]()[_0x2487('0x20')]();if(Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0xbc')]){_0x195263+=_0x4b3804[_0x2487('0x3a')];}if(_0x4b3804[_0x2487('0xaf')][_0x2487('0x71')](/<OTB User Next Turn: ([\+\-]\d+)>/i)){_0x195263+=parseInt(RegExp['$1']);}}if(_0x195263!==0x0){BattleManager[_0x2487('0x4d')](this,_0x195263,![]);}};Game_BattlerBase[_0x2487('0x7f')][_0x2487('0x68')]=function(){if(!!this[_0x2487('0x14a')]()&&this[_0x2487('0x14a')]()[_0x2487('0x20')]()){var _0xd0c58b=this[_0x2487('0x14a')]()[_0x2487('0x20')]();if(_0xd0c58b[_0x2487('0xaf')]['match'](/<OTB User Add Current Turn (?:Action|Actions): (\d+)>/i)){var _0x3df0be=parseInt(RegExp['$1']);this[_0x2487('0x41')](_0x3df0be,!![]);}if(_0xd0c58b[_0x2487('0xaf')][_0x2487('0x71')](/<OTB User Add Next Turn (?:Action|Actions): (\d+)>/i)){var _0x3df0be=parseInt(RegExp['$1']);this[_0x2487('0x41')](_0x3df0be,![]);}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Game_BattlerBase_hide___']=Game_BattlerBase['prototype'][_0x2487('0x121')];Game_BattlerBase[_0x2487('0x7f')][_0x2487('0x121')]=function(){var _0x393c27=this[_0x2487('0x1b')];Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x199')]['call'](this);if(BattleManager[_0x2487('0xca')]()&&_0x393c27!==this[_0x2487('0x1b')]&&!_0x393c27){BattleManager[_0x2487('0xd4')](this);}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x79')]=Game_BattlerBase[_0x2487('0x7f')]['appear'];Game_BattlerBase[_0x2487('0x7f')][_0x2487('0xee')]=function(){var _0x46f7be=this[_0x2487('0x1b')];Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x79')][_0x2487('0x1e')](this);if(BattleManager[_0x2487('0xca')]()&&_0x46f7be!==this[_0x2487('0x1b')]&&_0x46f7be){BattleManager[_0x2487('0x6b')](this);}};Game_BattlerBase[_0x2487('0x7f')]['otbInstanceName']=function(){if(this[_0x2487('0x50')]()){return _0x2487('0x84')+this[_0x2487('0xb1')]();}else{return _0x2487('0x16e')+this[_0x2487('0x18c')]();}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xf3')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x135')];Game_Battler['prototype'][_0x2487('0x135')]=function(){if(BattleManager[_0x2487('0xca')]()){this[_0x2487('0x134')]=0x0;}Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xf3')][_0x2487('0x1e')](this);};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x23')]=Game_Battler['prototype'][_0x2487('0x115')];Game_Battler[_0x2487('0x7f')][_0x2487('0x115')]=function(){if(BattleManager[_0x2487('0xca')]()){this['_otbTimesActedThisTurn']=0x0;}Olivia['OctoBattle'][_0x2487('0xef')]['___Game_Battler_onBattleEnd___'][_0x2487('0x1e')](this);};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x8e')]=Game_Battler[_0x2487('0x7f')]['performActionEnd'];Game_Battler[_0x2487('0x7f')]['performActionEnd']=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Game_Battler_performActionEnd___'][_0x2487('0x1e')](this);this['_otbTimesActedThisTurn']=this[_0x2487('0x134')]||0x0;this['_otbTimesActedThisTurn']+=0x1;};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x141')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x0')];Game_Battler[_0x2487('0x7f')]['onTurnEnd']=function(){if(BattleManager[_0x2487('0xca')]()){this[_0x2487('0x134')]=0x0;var _0x519210=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x18')];Olivia['OctoBattle'][_0x2487('0x149')][_0x2487('0x18')]=![];}Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x141')][_0x2487('0x1e')](this);if(BattleManager[_0x2487('0xca')]()){Olivia['OctoBattle'][_0x2487('0x149')]['RemoveRestrictCurrent']=_0x519210;}};if(Imported[_0x2487('0x1a4')]){Olivia['OctoBattle']['Battle'][_0x2487('0x28')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x53')];Game_Battler['prototype'][_0x2487('0x53')]=function(_0x22e9c9,_0x4f13ee){if(!this[_0x2487('0x2b')]){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x28')]['call'](this,_0x22e9c9,_0x4f13ee);}};Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x188')]=Game_Action[_0x2487('0x7f')]['customEffectEval'];Game_Action[_0x2487('0x7f')][_0x2487('0x53')]=function(_0x4bf2c5,_0x1f269c,_0x27ca14,_0x4e5e56,_0x38f270){if(this[_0x2487('0x2b')]||_0x4bf2c5[_0x2487('0x2b')]){return _0x38f270;}else{return Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x188')]['call'](this,_0x4bf2c5,_0x1f269c,_0x27ca14,_0x4e5e56,_0x38f270);}};}Game_Battler[_0x2487('0x7f')][_0x2487('0x41')]=function(_0x17e715,_0x2e411e){if(Olivia[_0x2487('0x13c')][_0x2487('0x149')]['AddedActionTimes']){var _0x17e715=Math[_0x2487('0x193')](0x1,_0x17e715);if(_0x2e411e){var _0x248d4b=BattleManager[_0x2487('0x170')];}else{var _0x248d4b=BattleManager[_0x2487('0x137')];}BattleManager[_0x2487('0xa7')](this,_0x248d4b,_0x17e715);}};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0xec')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x7')];Game_Battler[_0x2487('0x7f')][_0x2487('0x7')]=function(_0x4c5d9d){var _0x57d044=this[_0x2487('0xcb')]();var _0x408896=this[_0x2487('0x1b6')]();Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xec')][_0x2487('0x1e')](this,_0x4c5d9d);if($gameParty[_0x2487('0x119')]()&&BattleManager[_0x2487('0xca')]()){if(_0x57d044&&!this[_0x2487('0xcb')]()){BattleManager[_0x2487('0x61')]();}else if(this[_0x2487('0x1b6')]()>_0x408896){var _0x318330=this[_0x2487('0x1b6')]()>_0x408896;this[_0x2487('0x41')](_0x318330,!![]);this[_0x2487('0x41')](_0x318330,![]);}}};Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x87')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x19a')];Game_Battler['prototype'][_0x2487('0x19a')]=function(_0x3a6f6b){var _0x1c9c5a=this[_0x2487('0xcb')]();var _0x5a9943=this['makeActionTimes']();Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x87')][_0x2487('0x1e')](this,_0x3a6f6b);if(!this[_0x2487('0x2b')]&&$gameParty[_0x2487('0x119')]()&&BattleManager[_0x2487('0xca')]()){if(!_0x1c9c5a&&this[_0x2487('0xcb')]()){BattleManager[_0x2487('0x1b5')](this);}else if(this[_0x2487('0x1b6')]()>_0x5a9943){var _0x54eab9=this[_0x2487('0x1b6')]()>_0x5a9943;this[_0x2487('0x41')](_0x54eab9,!![]);this['otbAddActionTimes'](_0x54eab9,![]);}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Game_Battler_makeSpeed___']=Game_Battler[_0x2487('0x7f')][_0x2487('0x4a')];Game_Battler[_0x2487('0x7f')][_0x2487('0x4a')]=function(){if(!Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x55')]&&this[_0x2487('0xbb')][_0x2487('0x15d')]<=0x0){this[_0x2487('0xbb')][_0x2487('0x25')](new Game_Action(this));}Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x27')][_0x2487('0x1e')](this);};Olivia['OctoBattle']['Battle'][_0x2487('0x2')]=Game_Battler[_0x2487('0x7f')][_0x2487('0x38')];Game_Battler[_0x2487('0x7f')]['isUndecided']=function(){if(BattleManager[_0x2487('0xca')]()){return!![];}else{return Olivia[_0x2487('0x13c')]['Battle']['___Game_Battler_isUndecided___'][_0x2487('0x1e')](this);}};Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Game_Battler_consumeItem___']=Game_Battler[_0x2487('0x7f')][_0x2487('0x1b4')];Game_Battler[_0x2487('0x7f')]['consumeItem']=function(_0x1bffe0){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x124')][_0x2487('0x1e')](this,_0x1bffe0);if($gameParty[_0x2487('0x119')]()&&BattleManager[_0x2487('0xca')]()){this[_0x2487('0x7d')]();this[_0x2487('0x68')]();}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x114')]=Game_Party['prototype'][_0x2487('0x191')];Game_Party[_0x2487('0x7f')]['addActor']=function(_0x8936e9){var _0x596b7d=this[_0x2487('0xe8')][_0x2487('0x77')](_0x8936e9);Olivia['OctoBattle']['Battle']['___Game_Party_addActor___'][_0x2487('0x1e')](this,_0x8936e9);if(BattleManager[_0x2487('0xca')]()&&$gameParty[_0x2487('0x119')]()&&!_0x596b7d){var _0x46e235=$gameActors[_0x2487('0xf2')](_0x8936e9);if(!!_0x46e235){BattleManager[_0x2487('0x6b')](_0x46e235);}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x1b1')]=Game_Party[_0x2487('0x7f')][_0x2487('0xce')];Game_Party[_0x2487('0x7f')][_0x2487('0xce')]=function(_0x251708){var _0x3cfc7b=this[_0x2487('0xe8')]['contains'](_0x251708);Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x1b1')]['call'](this,_0x251708);if(BattleManager['isOTB']()&&$gameParty['inBattle']()&&_0x3cfc7b){var _0x21f0c6=$gameActors['actor'](_0x251708);if(!!_0x21f0c6){BattleManager[_0x2487('0xd4')](_0x21f0c6);}}};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x13e')]=Scene_Battle[_0x2487('0x7f')]['createHelpWindow'];Scene_Battle[_0x2487('0x7f')]['createHelpWindow']=function(){Olivia[_0x2487('0x13c')]['Battle']['___Scene_Battle_createHelpWindow___'][_0x2487('0x1e')](this);if(BattleManager[_0x2487('0xca')]()){this[_0x2487('0xfd')]();this['_helpWindow']['y']=Olivia[_0x2487('0x13c')]['OTB'][_0x2487('0xa3')];this[_0x2487('0x15e')]['y']=Olivia[_0x2487('0x13c')][_0x2487('0x149')]['LogWindowNewY'];}};Scene_Battle[_0x2487('0x7f')][_0x2487('0xfd')]=function(){this[_0x2487('0x36')]=new Window_OTBDisplay(this['_helpWindow']);this[_0x2487('0x4f')](this[_0x2487('0x36')]);};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x10b')]=Scene_Battle[_0x2487('0x7f')]['createActorCommandWindow'];Scene_Battle[_0x2487('0x7f')][_0x2487('0x78')]=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Scene_Battle_createActorCommandWindow___'][_0x2487('0x1e')](this);if(BattleManager[_0x2487('0xca')]()){this[_0x2487('0x19f')][_0x2487('0x109')](_0x2487('0x147'),this[_0x2487('0x18d')]['bind'](this));if(!Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x6e')]){this[_0x2487('0x19f')]['_handlers'][_0x2487('0xdb')]=undefined;}}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0x93')]=Scene_Battle[_0x2487('0x7f')][_0x2487('0x18d')];Scene_Battle[_0x2487('0x7f')][_0x2487('0x18d')]=function(){if(BattleManager[_0x2487('0xca')]()){BattleManager[_0x2487('0x128')]();}else{Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Scene_Battle_commandEscape___'][_0x2487('0x1e')](this);}};if(Imported[_0x2487('0xf8')]&&Imported['YEP_X_ActorPartySwitch']){Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Scene_Battle_postPartySwitch___']=Scene_Battle['prototype'][_0x2487('0x72')];Scene_Battle[_0x2487('0x7f')][_0x2487('0x72')]=function(_0x4ddf7e,_0x51a845,_0x1e19a0){Olivia['OctoBattle']['Battle'][_0x2487('0x101')]['call'](this,_0x4ddf7e,_0x51a845,_0x1e19a0);if(BattleManager[_0x2487('0xca')]()){this['otbPostPartySwitch'](_0x4ddf7e,_0x51a845,_0x1e19a0);}};Scene_Battle[_0x2487('0x7f')][_0x2487('0x51')]=function(_0x13658d,_0x2cd5cb,_0x3866ec){BattleManager['_subject']=_0x3866ec;BattleManager[_0x2487('0xdf')]()[_0x2487('0x24')][_0x2487('0x85')](_0x3866ec);BattleManager[_0x2487('0xd4')](_0x2cd5cb);var _0x5bc25a=Math[_0x2487('0x193')](0x0,_0x3866ec['makeActionTimes']()-_0x3866ec[_0x2487('0x134')]-0x1);if(_0x5bc25a>0x0){_0x3866ec[_0x2487('0x41')](_0x5bc25a,!![]);}_0x3866ec['otbAddActionTimes'](_0x3866ec[_0x2487('0x1b6')](),![]);this['_helpWindow'][_0x2487('0xcd')](BattleManager[_0x2487('0xf2')]());};}Spriteset_Battle[_0x2487('0x7f')][_0x2487('0x94')]=function(){if(Imported[_0x2487('0x13f')]){this[_0x2487('0x14c')]();}else{this[_0x2487('0x16b')][_0x2487('0x12d')](this[_0x2487('0x156')]);this[_0x2487('0x16b')]['removeChild'](this[_0x2487('0x9')]);}if(BattleManager[_0x2487('0xed')]()!==0x0){this[_0x2487('0x16b')][_0x2487('0x9b')][_0x2487('0x99')](this[_0x2487('0xcf')]);}if(Imported['YEP_ImprovedBattlebacks']){this['updateBattlebackGroupAdd']();}else{this[_0x2487('0x16b')][_0x2487('0x62')](this[_0x2487('0x9')],0x0);this[_0x2487('0x16b')][_0x2487('0x62')](this['_back1Sprite'],0x0);}};Spriteset_Battle[_0x2487('0x7f')][_0x2487('0xcf')]=function(_0x339e35,_0x13193c){var _0x52466b=BattleManager['getSpritePriority']();if(_0x339e35['_battler']&&_0x13193c[_0x2487('0xc8')]&&_0x52466b!==0x0){if(_0x52466b===0x1){if(_0x339e35[_0x2487('0xc8')][_0x2487('0x50')]()&&_0x13193c[_0x2487('0xc8')][_0x2487('0x1ae')]())return 0x1;if(_0x339e35['_battler'][_0x2487('0x1ae')]()&&_0x13193c[_0x2487('0xc8')][_0x2487('0x50')]())return-0x1;}else if(_0x52466b===0x2){if(_0x339e35['_battler'][_0x2487('0x50')]()&&_0x13193c[_0x2487('0xc8')][_0x2487('0x1ae')]())return-0x1;if(_0x339e35[_0x2487('0xc8')][_0x2487('0x1ae')]()&&_0x13193c[_0x2487('0xc8')][_0x2487('0x50')]())return 0x1;}}if(_0x339e35['z']<_0x13193c['z']){return-0x1;}else if(_0x339e35['z']>_0x13193c['z']){return 0x1;}else if(_0x339e35['y']<_0x13193c['y']){return-0x1;}else if(_0x339e35['y']>_0x13193c['y']){return 0x1;}else{return 0x0;}};function Sprite_OTBTurnOrder(){this['initialize'][_0x2487('0x110')](this,arguments);}Sprite_OTBTurnOrder[_0x2487('0x7f')]=Object[_0x2487('0x11b')](Sprite_Base['prototype']);Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x83')]=Sprite_OTBTurnOrder;Sprite_OTBTurnOrder[_0x2487('0x7f')]['initialize']=function(_0x432d25,_0x2da643,_0x3bac7e){this[_0x2487('0xc8')]=_0x432d25;this[_0x2487('0x138')]=_0x2da643||0x0;this['_sourceArray']=_0x3bac7e;this[_0x2487('0x12c')]();this[_0x2487('0xae')]=![];this[_0x2487('0xa4')]=![];Sprite_Base['prototype'][_0x2487('0xfb')]['call'](this);this[_0x2487('0xc5')]=0x0;this[_0x2487('0x185')]['x']=0.5;this[_0x2487('0x185')]['y']=0.5;this['createBackground1Sprite']();this['createBackground2Sprite']();this[_0x2487('0xc')]();};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xda')]=function(){return Window_Base[_0x2487('0x7f')][_0x2487('0xda')][_0x2487('0x1e')](this);};Sprite_OTBTurnOrder[_0x2487('0x7f')]['createConstants']=function(){this[_0x2487('0x3d')]=![];this[_0x2487('0xaa')]=0x0;this[_0x2487('0x56')]=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x104')];this['_opacityRate']=Olivia[_0x2487('0x13c')]['OTB'][_0x2487('0xe0')];this[_0x2487('0x1aa')]=![];this[_0x2487('0x9d')]=0x0;this['_x1']=BattleManager['otbDisplayWindow']()[_0x2487('0xf1')];this[_0x2487('0x1d')]=BattleManager[_0x2487('0xdf')]()[_0x2487('0x1d')];this[_0x2487('0x12b')]=BattleManager[_0x2487('0xdf')]()['_width1'];this[_0x2487('0x125')]=BattleManager['otbDisplayWindow']()[_0x2487('0x125')];};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x154')]=function(){var _0x162fec=this[_0x2487('0xda')]();this['x']=_0x162fec;this['y']=_0x162fec;var _0x5b65cb=Math[_0x2487('0x9e')](_0x162fec/0x2);this[_0x2487('0x140')]=new Sprite();this[_0x2487('0x190')](this['_background1Sprite']);this[_0x2487('0x140')][_0x2487('0x44')]=new Bitmap(_0x162fec,_0x162fec);var _0x12a83d=_0x2487('0x9f');if(this[_0x2487('0xc8')][_0x2487('0x50')]()){var _0x363ecb=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x91')];}else{var _0x363ecb=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x131')];}var _0x2ff4a5=[_0x5b65cb,0x0,0x0,_0x5b65cb,_0x5b65cb,_0x162fec,_0x162fec,_0x5b65cb];this['_background1Sprite'][_0x2487('0x44')]['drawOutlinePolygon'](_0x2ff4a5,_0x12a83d,_0x363ecb,0x1,0x1,!![]);this[_0x2487('0x140')][_0x2487('0x185')]['x']=0.5;this['_background1Sprite'][_0x2487('0x185')]['y']=0.5;};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x92')]=function(){var _0x53ff1a=this[_0x2487('0xda')]()*0x2;var _0xd6cd96=Math[_0x2487('0x9e')](_0x53ff1a/0x2);this[_0x2487('0x86')]=new Sprite();this['addChild'](this['_background2Sprite']);this[_0x2487('0x86')][_0x2487('0x44')]=new Bitmap(_0x53ff1a,_0x53ff1a);var _0x4d0dc4=_0x2487('0x9f');if(this[_0x2487('0xc8')][_0x2487('0x50')]()){var _0x13afbc=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x91')];}else{var _0x13afbc=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x131')];}var _0x529d16=[_0xd6cd96,0x0,0x0,_0xd6cd96,_0xd6cd96,_0x53ff1a,_0x53ff1a,_0xd6cd96];this[_0x2487('0x86')][_0x2487('0x44')][_0x2487('0xd0')](_0x529d16,_0x4d0dc4,_0x13afbc,0x1,0x1,!![]);this['_background2Sprite'][_0x2487('0x185')]['x']=0.5;this['_background2Sprite'][_0x2487('0x185')]['y']=0.5;this[_0x2487('0x86')]['opacity']=0x0;};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xc')]=function(){this[_0x2487('0x2e')]=new Sprite();this[_0x2487('0x190')](this[_0x2487('0x2e')]);this[_0x2487('0x2e')][_0x2487('0x185')]['x']=0.5;this[_0x2487('0x2e')][_0x2487('0x185')]['y']=0.5;this[_0x2487('0x2e')]['bitmap']=this[_0x2487('0x113')]();this['_battlerSprite'][_0x2487('0x44')][_0x2487('0xd')](this[_0x2487('0x5c')][_0x2487('0x74')](this));};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xd5')]=function(){return Imported[_0x2487('0x57')]&&this['_battler'][_0x2487('0x76')]();};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x113')]=function(){var _0x294bf2=this[_0x2487('0xc8')][_0x2487('0xb5')]();if(this[_0x2487('0xc8')][_0x2487('0x50')]()){if($gameSystem[_0x2487('0x1b2')]()&&!this[_0x2487('0xd5')]()){return ImageManager[_0x2487('0x166')](_0x294bf2);}else{_0x294bf2=this['_battler'][_0x2487('0x34')]();return ImageManager[_0x2487('0x176')](_0x294bf2);}}else{var _0xbe40ef=this[_0x2487('0xc8')][_0x2487('0x4b')]();this[_0x2487('0x42')]=_0x294bf2;this[_0x2487('0x19d')]=_0xbe40ef;if(this[_0x2487('0xd5')]()){this[_0x2487('0x42')]=dragonBonesIntegration[_0x2487('0x8')]['call'](this[_0x2487('0xc8')]);if($gameSystem[_0x2487('0x1b2')]()){return ImageManager[_0x2487('0x2d')](this['_battlerName'],_0xbe40ef);}else{return ImageManager[_0x2487('0x70')](this[_0x2487('0x42')],_0xbe40ef);}}else if(Imported[_0x2487('0x16c')]&&this[_0x2487('0xc8')][_0x2487('0x18f')]()){this[_0x2487('0x42')]=this[_0x2487('0xc8')][_0x2487('0x13b')]();return ImageManager[_0x2487('0x166')](this[_0x2487('0x42')]);}else if($gameSystem[_0x2487('0x1b2')]()){return ImageManager[_0x2487('0x2d')](_0x294bf2,_0xbe40ef);}else{return ImageManager[_0x2487('0x70')](_0x294bf2,_0xbe40ef);}}};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x5c')]=function(){this[_0x2487('0x189')]();this[_0x2487('0x1a0')]();this[_0x2487('0x3d')]=!![];};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x189')]=function(){var _0xf7352c=0x0;var _0x137aec=0x0;var _0x19feed=this['_battlerSprite'][_0x2487('0x44')][_0x2487('0x10e')];var _0x287d9b=this['_battlerSprite'][_0x2487('0x44')][_0x2487('0x102')];this[_0x2487('0x5f')]['x']=0x1;if(this['_battler'][_0x2487('0x50')]()){if($gameSystem[_0x2487('0x1b2')]()&&!this[_0x2487('0xd5')]()){_0x19feed/=0x9;_0x287d9b/=0x6;}else{var _0x349af2=this[_0x2487('0xc8')][_0x2487('0x12e')]();var _0x309afc=ImageManager['isBigCharacter'](this['_battler'][_0x2487('0x34')]());_0x19feed=this[_0x2487('0x2e')][_0x2487('0x44')][_0x2487('0x10e')]/(_0x309afc?0x3:0xc);_0x287d9b=this['_battlerSprite']['bitmap']['height']/(_0x309afc?0x4:0x8);_0xf7352c=(_0x349af2%0x4*0x3+0x1)*_0x19feed;_0x137aec=Math[_0x2487('0x116')](_0x349af2/0x4)*0x4*_0x287d9b;}}else if(this[_0x2487('0xd5')]()){_0x19feed*=0x1;_0x287d9b*=0x1;}else if(Imported['YEP_X_AnimatedSVEnemies']&&this[_0x2487('0xc8')][_0x2487('0x1ae')]()&&this['_battler'][_0x2487('0x18f')]()){_0x19feed/=0x9;_0x287d9b/=0x6;this[_0x2487('0x5f')]['x']=-0x1;}this[_0x2487('0x2e')]['setFrame'](_0xf7352c,_0x137aec,_0x19feed,_0x287d9b);};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x1a0')]=function(){var _0x3325f1=this[_0x2487('0xda')]();var _0x1f8c90=Math[_0x2487('0x193')](this['_battlerSprite'][_0x2487('0x10e')],this[_0x2487('0x2e')][_0x2487('0x102')]);if(_0x1f8c90>_0x3325f1){var _0x3631b4=_0x3325f1/_0x1f8c90;this[_0x2487('0x2e')][_0x2487('0x5f')]['x']=_0x3631b4;this[_0x2487('0x2e')]['scale']['y']=_0x3631b4;}this[_0x2487('0x160')]=_0x3631b4;this[_0x2487('0x47')]=Math[_0x2487('0x39')](0x1,0x2*this[_0x2487('0x160')]);};Sprite_OTBTurnOrder['prototype'][_0x2487('0x10')]=function(_0x20ea72){this['_previewMode']=!![];this['y']=0x0;if(this[_0x2487('0x11c')]===BattleManager[_0x2487('0x170')]){var _0x5734bf=Math[_0x2487('0x39')](this[_0x2487('0xda')](),Math[_0x2487('0x181')]((this[_0x2487('0x12b')]-this['lineHeight']())/(this[_0x2487('0x11c')][_0x2487('0x15d')]-0x1)));this['x']=this[_0x2487('0xf1')]+Math[_0x2487('0x9e')](this[_0x2487('0xda')]()/0x2)+_0x20ea72*_0x5734bf-Math[_0x2487('0x9e')](_0x5734bf/0x2);}else{var _0x5734bf=Math[_0x2487('0x39')](this[_0x2487('0xda')](),Math['ceil']((this[_0x2487('0x125')]-this[_0x2487('0xda')]())/(this[_0x2487('0x11c')][_0x2487('0x15d')]-0x1)));this['x']=this[_0x2487('0x1d')]+Math['round'](this['lineHeight']()/0x2)+_0x20ea72*_0x5734bf-0x4-Math[_0x2487('0x9e')](_0x5734bf/0x2);}this['_background1Sprite'][_0x2487('0xe5')]([0xff,0xff,0xff,0xff]);this['opacity']=0xff;};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x1af')]=function(){Sprite_Base[_0x2487('0x7f')][_0x2487('0x1af')][_0x2487('0x1e')](this);if(this[_0x2487('0xc8')]&&this[_0x2487('0x3d')]){this[_0x2487('0xc1')]();}this[_0x2487('0x17')]();if(!this[_0x2487('0xae')]){this['updateMovement']();this[_0x2487('0xd9')]();}};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xc1')]=function(){if(this[_0x2487('0xc8')][_0x2487('0x1ae')]()){if(this[_0x2487('0xd5')]()){var _0x2ee62e=dragonBonesIntegration[_0x2487('0x8')][_0x2487('0x1e')](this[_0x2487('0xc8')]);}else{var _0x2ee62e=this[_0x2487('0xc8')][_0x2487('0xb5')]();}if(this[_0x2487('0x42')]!==_0x2ee62e||this[_0x2487('0x19d')]!==this['_battler']['battlerHue']()){this[_0x2487('0x3d')]=![];this[_0x2487('0x12d')](this[_0x2487('0x2e')]);this[_0x2487('0xc')]();}}};Sprite_OTBTurnOrder['prototype'][_0x2487('0x85')]=function(_0x35133e){if(this[_0x2487('0xc8')]!==_0x35133e){this['_battler']=_0x35133e;this[_0x2487('0x3d')]=![];this[_0x2487('0x12d')](this[_0x2487('0x2e')]);this[_0x2487('0xc')]();}};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xc9')]=function(){if(this[_0x2487('0x56')]){var _0x19966c=this[_0x2487('0x56')];this['x']=(this['x']*(_0x19966c-0x1)+this[_0x2487('0xaa')])/_0x19966c;this['_moveDuration']--;}};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0x17')]=function(){if(this[_0x2487('0xa4')]&&this[_0x2487('0x48')]>0x0){this[_0x2487('0x48')]*=-0x1;}if(!!BattleManager[_0x2487('0x178')]){this[_0x2487('0xc5')]-=Math[_0x2487('0x181')](Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0xe0')]);}else if(this[_0x2487('0x48')]>0x0&&this[_0x2487('0xc5')]<0xff){this[_0x2487('0xc5')]+=this[_0x2487('0x48')];}else if(this[_0x2487('0x48')]<0x0&&this[_0x2487('0xc5')]>0x0){this[_0x2487('0xc5')]+=this[_0x2487('0x48')];}};Sprite_OTBTurnOrder[_0x2487('0x7f')][_0x2487('0xd9')]=function(){if(this['_battler']['isSelected']()){this['_selectionEffectCount']++;if(this[_0x2487('0x9d')]%0x1e<0xf){this['_battlerSprite'][_0x2487('0xe5')]([0xff,0xff,0xff,0x40]);}else{this[_0x2487('0x2e')][_0x2487('0xe5')]([0x0,0x0,0x0,0x0]);}this[_0x2487('0x2e')][_0x2487('0x5f')]['x']=this[_0x2487('0x47')];this['_battlerSprite'][_0x2487('0x5f')]['y']=this[_0x2487('0x47')];this['_background2Sprite'][_0x2487('0xc5')]=0xff;this[_0x2487('0x140')][_0x2487('0xc5')]=0x0;}else if(this[_0x2487('0x1aa')]&&this['x']===this[_0x2487('0xaa')]){this[_0x2487('0x2e')][_0x2487('0xe5')]([0x0,0x0,0x0,0x0]);this[_0x2487('0x2e')][_0x2487('0x5f')]['x']=Math['min'](this[_0x2487('0x47')],this[_0x2487('0x2e')][_0x2487('0x5f')]['x']+0.05);this['_battlerSprite'][_0x2487('0x5f')]['y']=Math[_0x2487('0x39')](this[_0x2487('0x47')],this[_0x2487('0x2e')][_0x2487('0x5f')]['y']+0.05);this['_background2Sprite'][_0x2487('0xc5')]=0xff;this['_background1Sprite'][_0x2487('0xc5')]=0x0;}else{this['_selectionEffectCount']=0x0;this[_0x2487('0x2e')][_0x2487('0xe5')]([0x0,0x0,0x0,0x0]);this[_0x2487('0x2e')][_0x2487('0x5f')]['x']=0x1*this[_0x2487('0x160')];this[_0x2487('0x2e')][_0x2487('0x5f')]['y']=0x1*this[_0x2487('0x160')];this[_0x2487('0x140')][_0x2487('0xc5')]=0xff;this[_0x2487('0x86')][_0x2487('0xc5')]=0x0;}};Sprite_OTBTurnOrder[_0x2487('0x7f')]['updatePosition']=function(){this['_moveDuration']=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x104')];var _0x560708=this[_0x2487('0x11c')][_0x2487('0x11d')](this[_0x2487('0xc8')]);var _0x47921b=_0x560708[this[_0x2487('0x138')]];if(this[_0x2487('0x138')]<0x0){this['_targetX']=this[_0x2487('0xda')]();this[_0x2487('0x1aa')]=!![];}else if(this[_0x2487('0x11c')]===BattleManager[_0x2487('0x170')]){var _0x1f3d6f=Math[_0x2487('0x39')](this['lineHeight'](),Math[_0x2487('0x181')]((this[_0x2487('0x12b')]-this[_0x2487('0xda')]())/(this[_0x2487('0x11c')][_0x2487('0x15d')]-0x1)));this['_targetX']=this[_0x2487('0xf1')]+Math[_0x2487('0x9e')](this[_0x2487('0xda')]()/0x2)+_0x47921b*_0x1f3d6f;}else{var _0x1f3d6f=Math['min'](this[_0x2487('0xda')](),Math['ceil']((this[_0x2487('0x125')]-this[_0x2487('0xda')]())/(this[_0x2487('0x11c')][_0x2487('0x15d')]-0x1)));this[_0x2487('0xaa')]=this[_0x2487('0x1d')]+Math[_0x2487('0x9e')](this[_0x2487('0xda')]()/0x2)+_0x47921b*_0x1f3d6f-0x4;}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xe9')]=Window_Selectable['prototype'][_0x2487('0x5d')];Window_Selectable[_0x2487('0x7f')][_0x2487('0x5d')]=function(_0x48334a){Olivia['OctoBattle']['Battle'][_0x2487('0xe9')][_0x2487('0x1e')](this,_0x48334a);if($gameParty[_0x2487('0x119')]()&&BattleManager[_0x2487('0xca')]()&&SceneManager[_0x2487('0x1b3')]instanceof Scene_Battle&&this['_otbTurnPreview']){if(_0x48334a>=0x0){this['otbCreateTurnPreview']();}else{this[_0x2487('0x43')]();}}};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0x9c')]=Window_Selectable[_0x2487('0x7f')][_0x2487('0x4e')];Window_Selectable[_0x2487('0x7f')][_0x2487('0x4e')]=function(){Olivia['OctoBattle'][_0x2487('0xef')]['Window_Selectable_deactivate']['call'](this);this[_0x2487('0x43')]();};Window_Selectable['prototype'][_0x2487('0xe7')]=function(){};Window_Selectable[_0x2487('0x7f')][_0x2487('0x43')]=function(){BattleManager[_0x2487('0x175')]=null;BattleManager[_0x2487('0xbe')]=!![];};Window_Selectable[_0x2487('0x7f')][_0x2487('0x1a8')]=function(_0x56f5cb){if(!!_0x56f5cb){DataManager[_0x2487('0x1a5')](_0x56f5cb);this['otbClearTurnPreview']();BattleManager['_requestNextTurnPreview']=_0x56f5cb;BattleManager[_0x2487('0xbe')]=![];}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xd2')]=Window_ActorCommand[_0x2487('0x7f')][_0x2487('0xfb')];Window_ActorCommand['prototype'][_0x2487('0xfb')]=function(){this[_0x2487('0x5')]=!![];Olivia[_0x2487('0x13c')]['Battle']['Window_ActorCommand_initialize'][_0x2487('0x1e')](this);};Olivia[_0x2487('0x13c')]['Battle'][_0x2487('0xad')]=Window_ActorCommand[_0x2487('0x7f')]['makeCommandList'];Window_ActorCommand[_0x2487('0x7f')][_0x2487('0x150')]=function(){Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xad')][_0x2487('0x1e')](this);if(this[_0x2487('0xb2')]&&Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x11')]){this[_0x2487('0x196')]();}};Window_ActorCommand[_0x2487('0x7f')][_0x2487('0x196')]=function(){this['addCommand'](TextManager[_0x2487('0x147')],_0x2487('0x147'),BattleManager[_0x2487('0x16a')]());};Window_ActorCommand[_0x2487('0x7f')]['otbCreateTurnPreview']=function(){if(this[_0x2487('0x179')]()===_0x2487('0xd6')){this[_0x2487('0x1a8')]($dataSkills[this[_0x2487('0xb2')][_0x2487('0x105')]()]);}else if(this[_0x2487('0x179')]()===_0x2487('0x4c')){this[_0x2487('0x1a8')]($dataSkills[this['_actor'][_0x2487('0x8d')]()]);}else{this[_0x2487('0x43')]();}};Olivia[_0x2487('0x13c')][_0x2487('0xef')][_0x2487('0xde')]=Window_BattleEnemy[_0x2487('0x7f')][_0x2487('0xfb')];Window_BattleEnemy[_0x2487('0x7f')][_0x2487('0xfb')]=function(_0x5646c6,_0x5a3516){this[_0x2487('0x5')]=!![];Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0xde')][_0x2487('0x1e')](this,_0x5646c6,_0x5a3516);};Window_BattleEnemy['prototype'][_0x2487('0xe7')]=function(){this[_0x2487('0x1a8')](BattleManager[_0x2487('0xab')]()[_0x2487('0x20')]());};Olivia['OctoBattle'][_0x2487('0xef')][_0x2487('0x2f')]=Window_BattleSkill['prototype']['initialize'];Window_BattleSkill['prototype'][_0x2487('0xfb')]=function(_0x223354,_0x2613c9,_0x4440a5,_0x4d09fd){this[_0x2487('0x5')]=!![];Olivia[_0x2487('0x13c')][_0x2487('0xef')]['___Window_BattleSkill_initialize___'][_0x2487('0x1e')](this,_0x223354,_0x2613c9,_0x4440a5,_0x4d09fd);};Window_BattleSkill['prototype'][_0x2487('0xe7')]=function(){if(!!this[_0x2487('0x20')]()){this[_0x2487('0x1a8')](this[_0x2487('0x20')]());}else{this[_0x2487('0x43')]();}};function Window_OTBDisplay(){this['initialize']['apply'](this,arguments);}Window_OTBDisplay[_0x2487('0x7f')]=Object[_0x2487('0x11b')](Window_Base[_0x2487('0x7f')]);Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x83')]=Window_OTBDisplay;Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0xfb')]=function(_0x5a7031){this['_helpWindow']=_0x5a7031;var _0x1a1d50=Olivia['OctoBattle']['OTB'][_0x2487('0x112')];var _0x444649=Olivia[_0x2487('0x13c')][_0x2487('0x149')]['DisplayY'];var _0xddad5e=Graphics[_0x2487('0x13')]-_0x1a1d50;if(Olivia[_0x2487('0x13c')][_0x2487('0x108')]&&Olivia[_0x2487('0x13c')][_0x2487('0x108')][_0x2487('0xe6')]){_0xddad5e-=Olivia[_0x2487('0x13c')][_0x2487('0x108')][_0x2487('0x31')];_0xddad5e-=Math['max'](Olivia[_0x2487('0x13c')][_0x2487('0x108')][_0x2487('0xa5')],Olivia[_0x2487('0x13c')][_0x2487('0x108')][_0x2487('0xc2')]);_0xddad5e-=Window_Base['_iconWidth']*(Olivia[_0x2487('0x13c')][_0x2487('0x108')]['StatesMax']+0.5);}else{_0xddad5e-=_0x1a1d50;}_0xddad5e=Math['round'](_0xddad5e);var _0x5462a3=this['lineHeight']()*0x3;this[_0x2487('0xe3')]();Window_Base[_0x2487('0x7f')][_0x2487('0xfb')][_0x2487('0x1e')](this,_0x1a1d50,_0x444649,_0xddad5e,_0x5462a3);this[_0x2487('0x5e')]();this[_0x2487('0xc5')]=0x0;this[_0x2487('0x198')]=0x0;this[_0x2487('0xfa')]();};Window_OTBDisplay['prototype'][_0x2487('0x30')]=function(){return 0x0;};Window_OTBDisplay['prototype'][_0x2487('0xe3')]=function(){BattleManager[_0x2487('0xf5')]=![];BattleManager[_0x2487('0x15c')]=![];BattleManager[_0x2487('0x171')]=![];BattleManager[_0x2487('0x14e')]=![];this[_0x2487('0x24')]=null;this[_0x2487('0x90')]=[];this[_0x2487('0x60')]=[];};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x5e')]=function(){this['_x1']=this[_0x2487('0xda')]()*0x2;this[_0x2487('0x1d')]=Math[_0x2487('0x181')](this[_0x2487('0x10e')]/0x2)+Math[_0x2487('0x9e')](Window_Base[_0x2487('0xb4')]/0x2)+0xc;this['_y']=this[_0x2487('0xda')]();this[_0x2487('0x12b')]=Math['ceil'](this[_0x2487('0x10e')]/0x2)-Math[_0x2487('0x9e')](this['lineHeight']()*2.5);this[_0x2487('0x125')]=this['width']-this['_x2'];this[_0x2487('0x13a')]=Olivia[_0x2487('0x13c')]['OTB'][_0x2487('0x97')];this[_0x2487('0x6c')]=Olivia['OctoBattle'][_0x2487('0x149')][_0x2487('0x184')];this[_0x2487('0x11f')]=new Sprite();this[_0x2487('0x190')](this[_0x2487('0x11f')]);};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0xfa')]=function(){this[_0x2487('0x18b')]['clear']();this[_0x2487('0x157')]();this[_0x2487('0xe2')]();};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x157')]=function(){this[_0x2487('0x111')](!![]);var _0x2e7cbd=[];var _0x22fb53=this[_0x2487('0xda')]();var _0x14f5d1=0x1;_0x2e7cbd=[_0x22fb53,0x0,0x0,_0x22fb53,_0x22fb53,_0x22fb53*0x2,_0x22fb53*0x2,_0x22fb53];this[_0x2487('0x18b')]['drawOutlinePolygon'](_0x2e7cbd,this[_0x2487('0x136')](),this['dimColor1'](),0x1,_0x14f5d1,!![]);_0x2e7cbd=[_0x22fb53*0x2+0x8,_0x22fb53-0x8,_0x22fb53*0x2,_0x22fb53,_0x22fb53*0x2+0x8,_0x22fb53+0x8,_0x22fb53*0x2+0xc,_0x22fb53+0x4,this[_0x2487('0xf1')]+this[_0x2487('0x12b')]-0x8,_0x22fb53+0x4,this[_0x2487('0xf1')]+this[_0x2487('0x12b')]-0x4,_0x22fb53+0x8,this['_x1']+this[_0x2487('0x12b')]+0x4,_0x22fb53,this[_0x2487('0xf1')]+this[_0x2487('0x12b')]-0x4,_0x22fb53-0x8,this['_x1']+this[_0x2487('0x12b')]-0x8,_0x22fb53-0x4,_0x22fb53*0x2+0xc,_0x22fb53-0x4];this[_0x2487('0x18b')][_0x2487('0xd0')](_0x2e7cbd,this[_0x2487('0x136')](),this[_0x2487('0x82')](),0x1,_0x14f5d1,!![]);_0x2e7cbd=[this[_0x2487('0x1d')]-0x4,_0x22fb53,this[_0x2487('0x1d')]+0x4,_0x22fb53+0x8,this[_0x2487('0x1d')]+0x8,_0x22fb53+0x4,this[_0x2487('0x1d')]+this[_0x2487('0x125')]-0xc,_0x22fb53+0x4,this[_0x2487('0x1d')]+this[_0x2487('0x125')]-0x8,_0x22fb53+0x8,this[_0x2487('0x1d')]+this[_0x2487('0x125')],_0x22fb53,this[_0x2487('0x1d')]+this[_0x2487('0x125')]-0x8,_0x22fb53-0x8,this['_x2']+this['_width2']-0xc,_0x22fb53-0x4,this[_0x2487('0x1d')]+0x8,_0x22fb53-0x4,this[_0x2487('0x1d')]+0x4,_0x22fb53-0x8];this[_0x2487('0x18b')]['drawOutlinePolygon'](_0x2e7cbd,this[_0x2487('0x136')](),this['dimColor1'](),0x1,_0x14f5d1,!![]);_0x2e7cbd=[this[_0x2487('0x1d')]-0xc,_0x22fb53,this[_0x2487('0x1d')]-0xc+_0x22fb53,_0x22fb53*0x2,this[_0x2487('0x1d')]-0x14+_0x22fb53,_0x22fb53*0x2,this[_0x2487('0x1d')]-0x14,_0x22fb53,this['_x2']-0x14+_0x22fb53,0x0,this[_0x2487('0x1d')]-0xc+_0x22fb53,0x0];this[_0x2487('0x18b')][_0x2487('0xd0')](_0x2e7cbd,this[_0x2487('0x136')](),this[_0x2487('0x82')](),0x1,_0x14f5d1,!![]);_0x2e7cbd=[this[_0x2487('0x1d')]-0x1c,_0x22fb53,this['_x2']-0x1c+_0x22fb53,_0x22fb53*0x2,this[_0x2487('0x1d')]-0x24+_0x22fb53,_0x22fb53*0x2,this[_0x2487('0x1d')]-0x24,_0x22fb53,this[_0x2487('0x1d')]-0x24+_0x22fb53,0x0,this[_0x2487('0x1d')]-0x1c+_0x22fb53,0x0];this[_0x2487('0x18b')][_0x2487('0xd0')](_0x2e7cbd,this[_0x2487('0x136')](),this[_0x2487('0x82')](),0x1,_0x14f5d1,!![]);};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0xe2')]=function(){this[_0x2487('0x29')]();this[_0x2487('0x111')](!![]);var _0x1d3402=this[_0x2487('0x18b')]['outlineColor'];var _0xdc70b7=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x19')];var _0x3838a5=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0xf7')];var _0x36849f=Olivia[_0x2487('0x13c')][_0x2487('0x149')]['CurrentTurnFontSize'];var _0x235468=Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x98')];this[_0x2487('0x18b')]['fontSize']=_0x36849f;this[_0x2487('0x18b')]['drawText'](_0xdc70b7,this['lineHeight'](),this[_0x2487('0xda')]()*0x2,this[_0x2487('0x12b')],_0x36849f,_0x2487('0xc4'));this[_0x2487('0x18b')]['fontSize']=_0x235468;this[_0x2487('0x18b')][_0x2487('0x37')](_0x3838a5,this[_0x2487('0x1d')],this[_0x2487('0xda')]()*0x2,this[_0x2487('0x125')],_0x235468,_0x2487('0xc4'));};Window_OTBDisplay['prototype'][_0x2487('0x1af')]=function(){Window_Base['prototype'][_0x2487('0x1af')][_0x2487('0x1e')](this);if(BattleManager[_0x2487('0x178')]){this[_0x2487('0x198')]-=Math[_0x2487('0x181')](Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0xe0')]);}else if(this[_0x2487('0x198')]<0xff){this[_0x2487('0x198')]+=Math['ceil'](Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0xe0')]/0x2);}if(!!this[_0x2487('0x35')]){this[_0x2487('0x12')]();}this['updateDisposeSprites']();this[_0x2487('0x148')]();};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x12')]=function(){if(this[_0x2487('0x35')]['visible']){this['y']=Math['min'](this[_0x2487('0x13a')],this['y']+this[_0x2487('0x6c')]);}else{this['y']=Math[_0x2487('0x193')](Olivia[_0x2487('0x13c')][_0x2487('0x149')][_0x2487('0x165')],this['y']-this[_0x2487('0x6c')]);}};Window_OTBDisplay[_0x2487('0x7f')]['disposeSprite']=function(_0x468a1b){_0x468a1b[_0x2487('0x48')]=Math[_0x2487('0x152')](_0x468a1b[_0x2487('0x48')])*-0x1;_0x468a1b[_0x2487('0xa4')]=!![];this[_0x2487('0x60')]['push'](_0x468a1b);};Window_OTBDisplay[_0x2487('0x7f')]['updateDisposeSprites']=function(){if(this['_disposedSprites'][_0x2487('0x15d')]>0x0&&this[_0x2487('0x60')][0x0]['opacity']<=0x0){this[_0x2487('0x11f')]['removeChild'](this['_disposedSprites'][_0x2487('0x21')]());}};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x6a')]=function(){if(this[_0x2487('0x187')]===undefined){this[_0x2487('0x187')]=[];this[_0x2487('0x162')](!![]);this[_0x2487('0x8f')]=[];this[_0x2487('0x162')](![]);BattleManager[_0x2487('0xf5')]=!![];BattleManager[_0x2487('0x15c')]=!![];BattleManager['_requestNextTurnUpdate']=!![];BattleManager[_0x2487('0x14e')]=!![];}else{this[_0x2487('0xbf')]();this[_0x2487('0x162')](![]);BattleManager[_0x2487('0xf5')]=!![];BattleManager[_0x2487('0x15c')]=![];BattleManager[_0x2487('0x171')]=!![];BattleManager[_0x2487('0x14e')]=![];}};Window_OTBDisplay[_0x2487('0x7f')]['giveTurnSpritesToNewArray']=function(){while(this[_0x2487('0x187')]['length']>0x0){this[_0x2487('0x16d')](this[_0x2487('0x187')][_0x2487('0x21')]());}while(this['_nextTurnSprites'][_0x2487('0x15d')]>0x0){var _0x4feaac=this[_0x2487('0x8f')][_0x2487('0x21')]();_0x4feaac[_0x2487('0x11c')]=BattleManager[_0x2487('0x170')];this[_0x2487('0x187')][_0x2487('0x25')](_0x4feaac);}};Window_OTBDisplay['prototype'][_0x2487('0x162')]=function(_0x411e3c){if(_0x411e3c){var _0x3e093d=BattleManager[_0x2487('0x170')];var _0x199359=this['_currentTurnSprites'];}else{var _0x3e093d=BattleManager[_0x2487('0x137')];var _0x199359=this[_0x2487('0x8f')];}var _0x16beb3={};for(var _0x2f3c06=0x0;_0x2f3c06<_0x3e093d['length'];_0x2f3c06++){var _0x1ec701=_0x3e093d[_0x2f3c06];_0x16beb3[_0x1ec701[_0x2487('0xa0')]()]=_0x16beb3[_0x1ec701[_0x2487('0xa0')]()]||0x0;var _0x56f850=new Sprite_OTBTurnOrder(_0x1ec701,_0x16beb3[_0x1ec701[_0x2487('0xa0')]()],_0x3e093d);_0x16beb3[_0x1ec701[_0x2487('0xa0')]()]+=0x1;this[_0x2487('0x11f')][_0x2487('0x190')](_0x56f850);_0x199359[_0x2487('0x25')](_0x56f850);if(!_0x411e3c){_0x56f850['x']=this[_0x2487('0x10e')];}}};Window_OTBDisplay['prototype'][_0x2487('0x164')]=function(_0x511552,_0x352313){if(_0x352313){var _0x444a76=BattleManager[_0x2487('0x170')];var _0x4c0c07=this[_0x2487('0x187')];var _0x45853d=this[_0x2487('0xf1')]+this['_width1'];BattleManager[_0x2487('0xf5')]=!![];}else{var _0x444a76=BattleManager['_nextTurnActionBattlers'];var _0x4c0c07=this[_0x2487('0x8f')];var _0x45853d=this[_0x2487('0x1d')]+this[_0x2487('0x125')];BattleManager[_0x2487('0x171')]=!![];}var _0x262023={};_0x262023[_0x511552[_0x2487('0xa0')]()]=_0x262023[_0x511552[_0x2487('0xa0')]()]||0x0;var _0x1146a0=_0x444a76[_0x2487('0x11d')](_0x511552);while(_0x1146a0[_0x2487('0x15d')]>0x0){var _0x6f6ab4=_0x1146a0[_0x2487('0x21')]();var _0x45515a=new Sprite_OTBTurnOrder(_0x511552,_0x262023[_0x511552[_0x2487('0xa0')]()],_0x444a76);_0x262023[_0x511552[_0x2487('0xa0')]()]+=0x1;this[_0x2487('0x11f')][_0x2487('0x190')](_0x45515a);_0x4c0c07['splice'](_0x6f6ab4,0x0,_0x45515a);_0x45515a['x']=_0x45853d;}};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x14f')]=function(_0x369477,_0x4105bf){if(_0x4105bf){var _0x36174d=BattleManager['_actionBattlers'];var _0x4ed87f=this[_0x2487('0x187')];var _0x27d648=this[_0x2487('0xf1')]+this[_0x2487('0x12b')];BattleManager[_0x2487('0xf5')]=!![];}else{var _0x36174d=BattleManager[_0x2487('0x137')];var _0x4ed87f=this[_0x2487('0x8f')];var _0x27d648=this[_0x2487('0x1d')]+this['_width2'];BattleManager[_0x2487('0x171')]=!![];}var _0x304b63={};var _0x14ab46=_0x36174d[_0x2487('0x11d')](_0x369477);var _0x7a2700=_0x14ab46[_0x2487('0x15d')]-0x1;var _0x67a3e3=new Sprite_OTBTurnOrder(_0x369477,_0x7a2700,_0x36174d);_0x4ed87f[_0x2487('0x25')](_0x67a3e3);this['_spriteContainer']['addChild'](_0x67a3e3);_0x67a3e3['x']=_0x27d648;};Window_OTBDisplay['prototype'][_0x2487('0x132')]=function(){if(!!this[_0x2487('0x24')]){this[_0x2487('0x16d')](this['_subjectSprite']);this['_subjectSprite']=null;}for(var _0x44382a=0x0;_0x44382a<this[_0x2487('0x187')][_0x2487('0x15d')];_0x44382a++){var _0x2db30f=this[_0x2487('0x187')][_0x44382a];if(_0x2db30f[_0x2487('0xc8')]===BattleManager[_0x2487('0x69')]){_0x2db30f[_0x2487('0x138')]-=0x1;if(_0x2db30f[_0x2487('0x138')]===-0x1){this['_subjectSprite']=_0x2db30f;this['_subjectSprite'][_0x2487('0x3b')]();this[_0x2487('0x187')][_0x2487('0x12a')](this[_0x2487('0x187')][_0x2487('0x103')](_0x2db30f),0x1);_0x44382a--;BattleManager['_requestCurrentTurnUpdate']=!![];}else if(_0x2db30f['_instance']<-0x1){this[_0x2487('0x16d')](_0x2db30f);this[_0x2487('0x187')][_0x2487('0x12a')](this[_0x2487('0x187')][_0x2487('0x103')](_0x2db30f),0x1);_0x44382a--;BattleManager[_0x2487('0xf5')]=!![];}}}};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x148')]=function(){if(BattleManager[_0x2487('0x173')]){this['updateClearUnableBattlers'](this[_0x2487('0x187')]);this[_0x2487('0x120')](this[_0x2487('0x8f')]);}if(BattleManager[_0x2487('0xf5')]){this[_0x2487('0xeb')](!![]);}if(BattleManager[_0x2487('0x171')]){this['updateTurnSpriteLocations'](![]);}if(BattleManager[_0x2487('0xe')]){this[_0x2487('0x10a')](!![]);}if(BattleManager['_requestNextTurnSpriteReorder']){this[_0x2487('0x10a')](![]);}if(BattleManager['_requestNextTurnPreview']){this[_0x2487('0xd7')]();}if(BattleManager[_0x2487('0xbe')]){this[_0x2487('0xb6')]();}};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x120')]=function(_0x1798c1){BattleManager['_requestClearUnableBattlers']=![];for(var _0x46fe2a=0x0;_0x46fe2a<_0x1798c1[_0x2487('0x15d')];_0x46fe2a++){var _0x45010b=_0x1798c1[_0x46fe2a];if(!!_0x45010b&&BattleManager[_0x2487('0x10c')](_0x45010b[_0x2487('0xc8')],_0x45010b[_0x2487('0x11c')])){this[_0x2487('0x16d')](_0x45010b);_0x1798c1[_0x2487('0x12a')](_0x46fe2a,0x1);_0x46fe2a--;}}};Window_OTBDisplay[_0x2487('0x7f')]['updateTurnSpriteLocations']=function(_0x1430d3){if(_0x1430d3){var _0x56492f=this['_currentTurnSprites'];var _0x80694c=BattleManager[_0x2487('0x15c')];BattleManager[_0x2487('0xf5')]=![];BattleManager['_requestCurrentTurnUpdateInstantly']=![];}else{var _0x56492f=this[_0x2487('0x8f')];var _0x80694c=BattleManager['_requestNextTurnUpdateInstantly'];BattleManager[_0x2487('0x171')]=![];BattleManager['_requestNextTurnUpdateInstantly']=![];}for(var _0x25b61f=0x0;_0x25b61f<_0x56492f[_0x2487('0x15d')];_0x25b61f++){var _0x386f2a=_0x56492f[_0x25b61f];if(!_0x386f2a){continue;}_0x386f2a[_0x2487('0x3b')]();if(_0x80694c){_0x386f2a['x']=_0x386f2a[_0x2487('0xaa')];_0x386f2a[_0x2487('0x56')]=0x1;}}};Window_OTBDisplay['prototype'][_0x2487('0x10a')]=function(_0x2ae857){if(_0x2ae857){var _0x3e7f4c=BattleManager['_actionBattlers'];var _0x332432=this['_currentTurnSprites'];BattleManager['_requestCurrentTurnUpdate']=!![];BattleManager['_requestCurrentTurnSpriteReorder']=![];}else{var _0x3e7f4c=BattleManager[_0x2487('0x137')];var _0x332432=this[_0x2487('0x8f')];BattleManager[_0x2487('0x171')]=!![];BattleManager[_0x2487('0xc7')]=![];}_0x332432[_0x2487('0x99')](function(_0x308e10,_0x4eaf52){return _0x308e10['_targetX']-_0x4eaf52[_0x2487('0xaa')];});this[_0x2487('0x11f')]['children'][_0x2487('0x99')](function(_0x4676be,_0x53a6c8){return _0x4676be[_0x2487('0xaa')]-_0x53a6c8[_0x2487('0xaa')];});};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0xd7')]=function(){this[_0x2487('0x64')]=BattleManager[_0x2487('0x175')];if(!this[_0x2487('0x64')]){return;}BattleManager[_0x2487('0x175')]=null;this[_0x2487('0xb6')]();this['updateNextTurnPreviewUser']();this[_0x2487('0x26')]();};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x106')]=function(){var _0x4a56fc=0x0;if(Olivia['OctoBattle'][_0x2487('0x149')][_0x2487('0xbc')]){_0x4a56fc+=this['_previewItem'][_0x2487('0x3a')];}if(this[_0x2487('0x64')][_0x2487('0xaf')][_0x2487('0x71')](/<OTB User Next Turn: ([\+\-]\d+)>/i)){_0x4a56fc+=parseInt(RegExp['$1']);}var _0x43f30c=BattleManager[_0x2487('0x69')];var _0x36a40c=BattleManager['_nextTurnActionBattlers'];this['createPreviewSprite'](_0x43f30c,_0x36a40c,_0x4a56fc);};Window_OTBDisplay[_0x2487('0x7f')]['createPreviewSprite']=function(_0x5c7ecd,_0x360b8e,_0x4e9a38){if(_0x4e9a38!==0x0&&_0x360b8e[_0x2487('0x77')](_0x5c7ecd)){_0x4e9a38+=_0x4e9a38>0x0?0x0:-0x1;var _0x38fb34=_0x360b8e[_0x2487('0x11d')](_0x5c7ecd);var _0x334c7b=BattleManager[_0x2487('0x1')](_0x360b8e);for(var _0x115176=0x0;_0x115176<_0x38fb34[_0x2487('0x15d')];_0x115176++){var _0x5f0d46=(_0x38fb34[_0x115176]-_0x4e9a38)[_0x2487('0x7c')](_0x334c7b,_0x360b8e[_0x2487('0x15d')]);var _0x1361e7=new Sprite_OTBTurnOrder(_0x5c7ecd,_0x115176,_0x360b8e);this[_0x2487('0x11f')]['addChild'](_0x1361e7);this[_0x2487('0x90')]['push'](_0x1361e7);_0x1361e7[_0x2487('0x10')](_0x5f0d46);}}};Window_OTBDisplay[_0x2487('0x7f')]['updateNextTurnPreviewTargets']=function(){var _0x460bce=this[_0x2487('0x163')]();if(_0x460bce[_0x2487('0x15d')]>0x0){var _0x109c2d=0x0;var _0x34a5d2=0x0;var _0x4731a6=0x0;if(this[_0x2487('0x64')][_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Follow Turn: ([\+\-]\d+)>/i)){_0x109c2d+=parseInt(RegExp['$1']);}if(this[_0x2487('0x64')][_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Current Turn: ([\+\-]\d+)>/i)){_0x34a5d2+=parseInt(RegExp['$1']);}if(this[_0x2487('0x64')][_0x2487('0xaf')][_0x2487('0x71')](/<OTB Target Next Turn: ([\+\-]\d+)>/i)){_0x4731a6+=parseInt(RegExp['$1']);}for(var _0x5a6658=0x0;_0x5a6658<_0x460bce['length'];_0x5a6658++){var _0x3a0902=_0x460bce[_0x5a6658];if(_0x3a0902[_0x2487('0x3a')]()!==Infinity){if(BattleManager[_0x2487('0x170')][_0x2487('0x77')](_0x3a0902)){_0x34a5d2+=_0x109c2d;}else{_0x4731a6+=_0x109c2d;}this[_0x2487('0x197')](_0x3a0902,BattleManager[_0x2487('0x170')],_0x34a5d2);this[_0x2487('0x197')](_0x3a0902,BattleManager['_nextTurnActionBattlers'],_0x4731a6);}}}};Window_OTBDisplay[_0x2487('0x7f')][_0x2487('0x163')]=function(){var _0x2cd113=[];var _0x1e8748=BattleManager[_0x2487('0x1f')]();for(var _0x2db36c=0x0;_0x2db36c<_0x1e8748[_0x2487('0x15d')];_0x2db36c++){var _0x505df8=_0x1e8748[_0x2db36c];if(!!_0x505df8&&_0x505df8['isSelected']()){_0x2cd113[_0x2487('0x25')](_0x505df8);}}return _0x2cd113;};Window_OTBDisplay['prototype'][_0x2487('0xb6')]=function(){BattleManager[_0x2487('0xbe')]=![];while(this[_0x2487('0x90')][_0x2487('0x15d')]>0x0){var _0x18ec74=this['_previewSprites'][_0x2487('0x21')]();this['disposeSprite'](_0x18ec74);}};}